@@ -1,4 +1,4 @@
-/*  Misfit Model 3D
+/*  Maverick Model 3D
  * 
  *  Copyright (c) 2004-2007 Kevin Worcester
  * 
@@ -30,7 +30,7 @@
 
 #include <list>
 #include <QtCore/QObject>
-#include <QtGui/QApplication>
+#include <QtWidgets/QApplication>
 
 using std::list;
 
@@ -57,7 +57,7 @@ bool FaceOutCommand::activated( int arg, Model * model )
       }
    }
 
-   model_status( model, StatusNormal, STATUSTIME_SHORT, qApp->translate( "Command", "Normals Face Out" ).toUtf8() );
+   model_status( model, StatusNormal, STATUSTIME_SHORT, "%s", qApp->translate( "Command", "Normals Face Out" ).toUtf8().data() );
 
    return true;
 }
