@@ -85,7 +85,7 @@ static ScrollButtonT s_buttons[ ModelViewport::ScrollButtonMAX ] =
 static Matrix s_mat;
 
 ModelViewport::ModelViewport( QWidget * parent )
-   : QGLWidget( parent ),
+   : QOpenGLWidget( parent ),
      m_model( NULL ),
      m_operation( MO_None ),
      m_activeButton( Qt::NoButton ),
@@ -126,8 +126,6 @@ ModelViewport::ModelViewport( QWidget * parent )
    g_prefs.setDefault( "ui_3dgrid_xz", 1 );
    g_prefs.setDefault( "ui_3dgrid_yz", 0 );
 
-   setAutoBufferSwap( false );
-
    setFocusPolicy( Qt::WheelFocus );
    setMinimumSize( 220, 180 );
 
@@ -365,9 +363,7 @@ void ModelViewport::paintGL()
             break;
          default:
             log_error( "Unknown ViewDirection: %d\n", m_viewDirection );
-            swapBuffers();
             return;
-            break;
       }
 
       m.apply( viewPoint );
@@ -518,8 +514,6 @@ void ModelViewport::paintGL()
    }
 
    checkGlErrors();
-
-   swapBuffers();
 }
 
 void ModelViewport::drawGridLines()
@@ -777,6 +771,7 @@ void ModelViewport::drawGridLines()
             break;
       }
 
+#if 0 // FIXME: renderText() exists in QGLWidget but not QOpenGLWidget
       g_prefs.setDefault( "ui_render_text", 0 );
       if ( g_prefs( "ui_render_text" ).intValue() != 0 )
       {
@@ -787,6 +782,7 @@ void ModelViewport::drawGridLines()
          text.sprintf( "%g", m_unitWidth );
          renderText( 2, this->height() - 12, text, QFont( "Sans", 10 ) );
       }
+#endif
    }
 }
 
@@ -861,8 +857,8 @@ void ModelViewport::drawBackground()
          m_model->getBackgroundCenter( index, cenX, cenY, cenZ );
 
          glBindTexture( GL_TEXTURE_2D, m_backgroundTexture );
-         glTexParameteri( GL_TEXTURE_2D, GL_TEXTURE_WRAP_S, GL_CLAMP  );
-         glTexParameteri( GL_TEXTURE_2D, GL_TEXTURE_WRAP_T, GL_CLAMP  );
+         glTexParameteri( GL_TEXTURE_2D, GL_TEXTURE_WRAP_S, GL_CLAMP_TO_EDGE );
+         glTexParameteri( GL_TEXTURE_2D, GL_TEXTURE_WRAP_T, GL_CLAMP_TO_EDGE );
          glEnable( GL_TEXTURE_2D );
 
          glBegin( GL_QUADS );
@@ -1149,7 +1145,7 @@ void ModelViewport::adjustViewport()
 {
    setViewportDraw();
 
-   updateGL();
+   update();
 }
 
 void ModelViewport::setViewportDraw()
@@ -1300,7 +1296,7 @@ void ModelViewport::setViewportOverlay()
 
 void ModelViewport::wheelEvent( QWheelEvent * e )
 {
-   if ( e->delta() > 0 )
+   if ( e->angleDelta().y() > 0 )
    {
       if ( (e->modifiers() & Qt::ControlModifier) == Qt::ControlModifier )
       {
@@ -1311,7 +1307,7 @@ void ModelViewport::wheelEvent( QWheelEvent * e )
          zoomIn();
       }
    }
-   else
+   else if ( e->angleDelta().y() < 0 )
    {
       if ( (e->modifiers() & Qt::ControlModifier) == Qt::ControlModifier )
       {
@@ -1336,10 +1332,9 @@ void ModelViewport::zoomIn()
       m_unitWidth = getUnitWidth();
       char str[80];
       PORT_snprintf( str, sizeof(str), "Units: %g", m_unitWidth );
-      model_status( m_model, StatusNormal, STATUSTIME_NONE, str );
+      model_status( m_model, StatusNormal, STATUSTIME_NONE, "%s", str );
 
-      QString zoomStr;
-      zoomStr.sprintf( "%f", m_zoomLevel );
+      QString zoomStr = QString::asprintf( "%f", m_zoomLevel );
       emit zoomLevelChanged( zoomStr );
 
       makeCurrent();
@@ -1359,10 +1354,9 @@ void ModelViewport::zoomOut()
       m_unitWidth = getUnitWidth();
       char str[80];
       PORT_snprintf( str, sizeof(str), "Units: %g", m_unitWidth );
-      model_status( m_model, StatusNormal, STATUSTIME_NONE, str );
+      model_status( m_model, StatusNormal, STATUSTIME_NONE, "%s", str );
 
-      QString zoomStr;
-      zoomStr.sprintf( "%f", m_zoomLevel );
+      QString zoomStr = QString::asprintf( "%f", m_zoomLevel );
       emit zoomLevelChanged( zoomStr );
 
       makeCurrent();
@@ -1614,7 +1608,7 @@ void ModelViewport::mouseReleaseEvent( QMouseEvent * e )
          m_overlayButton = ScrollButtonMAX;
          m_scrollTimer->stop();
 
-         model_status( m_model, StatusNormal, STATUSTIME_SHORT, tr("Use the middle mouse button to drag/pan the viewport").toUtf8() );
+         model_status( m_model, StatusNormal, STATUSTIME_SHORT, "%s", tr("Use the middle mouse button to drag/pan the viewport").toUtf8().data() );
       }
       m_activeButton = Qt::NoButton;
       m_operation    = MO_None;
@@ -1660,7 +1654,7 @@ void ModelViewport::mouseMoveEvent( QMouseEvent * e )
       char str[80];
       PORT_snprintf( str, sizeof(str), "Units: %g  (%g, %g, %g)",
             m_unitWidth, pos[0], pos[1], pos[2] );
-      model_status( m_model, StatusNormal, STATUSTIME_NONE, str );
+      model_status( m_model, StatusNormal, STATUSTIME_NONE, "%s", str );
    }
    else
    {
@@ -2067,7 +2061,7 @@ void ModelViewport::keyPressEvent( QKeyEvent * e )
             break;
 
          default:
-            QGLWidget::keyPressEvent( e );
+            QOpenGLWidget::keyPressEvent( e );
             return;
             break;
       }
@@ -2296,8 +2290,7 @@ void ModelViewport::setZoomLevel( double zoom )
       makeCurrent();
       adjustViewport();
 
-      QString zoomStr;
-      zoomStr.sprintf( "%f", m_zoomLevel );
+      QString zoomStr = QString::asprintf( "%f", m_zoomLevel );
       emit zoomLevelChanged( zoomStr );
    }
 }
@@ -2360,7 +2353,7 @@ void ModelViewport::focusInEvent( QFocusEvent * e )
    glClearColor( m_backColor.red() / 256.0, 
          m_backColor.green() / 256.0, 
          m_backColor.blue() / 256.0, 1.0f );
-   updateGL();
+   update();
 }
 
 void ModelViewport::focusOutEvent( QFocusEvent * e )
@@ -2372,7 +2365,7 @@ void ModelViewport::focusOutEvent( QFocusEvent * e )
    glClearColor( m_backColor.red() / 256.0, 
          m_backColor.green() / 256.0, 
          m_backColor.blue() / 256.0, 1.0f );
-   updateGL();
+   update();
 }
 
 /*
@@ -2797,7 +2790,7 @@ int ModelViewport::constructButtonState( QMouseEvent * e )
 
 void ModelViewport::updateView()
 {
-   updateGL();
+   update();
    StatusObject * bar = model_status_get_object( m_model );
    bar->setVertices(   m_model->getVertexCount(),    m_model->getSelectedVertexCount() );
    bar->setFaces(      m_model->getTriangleCount(),  m_model->getSelectedTriangleCount() );
@@ -2818,13 +2811,13 @@ void ModelViewport::update3dView()
 void ModelViewport::addDecal( Decal * decal )
 {
    m_decals.push_back( decal );
-   updateGL();
+   update();
 }
 
 void ModelViewport::removeDecal( Decal * decal )
 {
    m_decals.remove( decal );
-   updateGL();
+   update();
 }
 
 void ModelViewport::frameArea( double x1, double y1, double z1, double x2, double y2, double z2 )
@@ -3031,8 +3024,7 @@ void ModelViewport::frameArea( double x1, double y1, double z1, double x2, doubl
       }
    }
 
-   QString zoomStr;
-   zoomStr.sprintf( "%f", m_zoomLevel );
+   QString zoomStr = QString::asprintf( "%f", m_zoomLevel );
    emit zoomLevelChanged( zoomStr );
 
    makeCurrent();
@@ -3047,25 +3039,25 @@ void ModelViewport::checkGlErrors()
       switch ( error )
       {
          case GL_INVALID_VALUE:
-            model_status( m_model, StatusNormal, STATUSTIME_NONE, tr("OpenGL error = Invalid Value").toUtf8() );
+            model_status( m_model, StatusNormal, STATUSTIME_NONE, "%s", tr("OpenGL error = Invalid Value").toUtf8().data() );
             break;
          case GL_INVALID_ENUM:
-            model_status( m_model, StatusNormal, STATUSTIME_NONE, tr("OpenGL error = Invalid Enum").toUtf8() );
+            model_status( m_model, StatusNormal, STATUSTIME_NONE, "%s", tr("OpenGL error = Invalid Enum").toUtf8().data() );
             break;
          case GL_INVALID_OPERATION:
-            model_status( m_model, StatusNormal, STATUSTIME_NONE, tr("OpenGL error = Invalid Operation").toUtf8() );
+            model_status( m_model, StatusNormal, STATUSTIME_NONE, "%s", tr("OpenGL error = Invalid Operation").toUtf8().data() );
             break;
          case GL_STACK_OVERFLOW:
-            model_status( m_model, StatusNormal, STATUSTIME_NONE, tr("OpenGL error = Stack Overflow").toUtf8() );
+            model_status( m_model, StatusNormal, STATUSTIME_NONE, "%s", tr("OpenGL error = Stack Overflow").toUtf8().data() );
             break;
          case GL_STACK_UNDERFLOW:
-            model_status( m_model, StatusNormal, STATUSTIME_NONE, tr("OpenGL error = Stack Underflow").toUtf8() );
+            model_status( m_model, StatusNormal, STATUSTIME_NONE, "%s", tr("OpenGL error = Stack Underflow").toUtf8().data() );
             break;
          case GL_OUT_OF_MEMORY:
-            model_status( m_model, StatusNormal, STATUSTIME_NONE, tr("OpenGL error = Out Of Memory").toUtf8() );
+            model_status( m_model, StatusNormal, STATUSTIME_NONE, "%s", tr("OpenGL error = Out Of Memory").toUtf8().data() );
             break;
          default:
-            model_status( m_model, StatusNormal, STATUSTIME_NONE, tr("OpenGL error = Unknown").toUtf8() );
+            model_status( m_model, StatusNormal, STATUSTIME_NONE, "%s", tr("OpenGL error = Unknown").toUtf8().data() );
             break;
       }
    }
@@ -3106,7 +3098,7 @@ void ModelViewport::copyContentsToTexture( Texture * tex )
       tex->m_format = Texture::FORMAT_RGBA;
 
       makeCurrent();
-      updateGL();
+      update();
 
       glReadPixels( 0, 0, w, h, GL_RGBA, GL_UNSIGNED_BYTE, tex->m_data );
    }
@@ -3123,7 +3115,7 @@ void ModelViewport::updateCaptureGL()
 {
    m_capture = true;
    makeCurrent();
-   updateGL();
+   update();
    m_capture = false;
 }
 
