@@ -88,7 +88,9 @@ AnimWidget::AnimWidget( Model * model, bool isUndo, QWidget * parent )
      m_model( model ),
      m_playing( false ),
      m_undoing( isUndo ),
-     m_ignoreChange( false )
+     m_ignoreChange( false ),
+     m_changeFrameFocused( false ),
+     m_changeFrameDeferred( false )
 {
    setupUi( this );
 
@@ -249,8 +251,7 @@ void AnimWidget::setCurrentFrame( int frame )
    {
       m_currentFrame = frame - 1;
       QString str = tr("Frame: ");
-      QString numStr;
-      numStr.sprintf( "%03d", frame );
+      QString numStr = QString::asprintf( "%03d", frame );
       m_countLabel->setText( str + numStr );
    }
    else
@@ -301,8 +302,22 @@ void AnimWidget::changeFPS()
    }
 }
 
+void AnimWidget::changeFrameCountFocusIn()
+{
+   m_changeFrameFocused = true;
+
+   // Loose focus when clicking outside of frame count widget.
+   setFocusPolicy( Qt::ClickFocus );
+}
+
 void AnimWidget::changeFrameCount()
 {
+   if ( m_changeFrameFocused )
+   {
+      m_changeFrameDeferred = true;
+      return;
+   }
+
    if ( !m_ignoreChange )
    {
       if ( m_animCount > 0 )
@@ -320,6 +335,21 @@ void AnimWidget::changeFrameCount()
    }
 }
 
+void AnimWidget::changeFrameCountFocusOut()
+{
+   if ( m_changeFrameFocused )
+   {
+      m_changeFrameFocused = false;
+      setFocusPolicy( Qt::NoFocus );
+
+      if ( m_changeFrameDeferred )
+      {
+         m_changeFrameDeferred = true;
+         changeFrameCount();
+      }
+   }
+}
+
 void AnimWidget::clearFrame()
 {
    Model::AnimationModeE mode = m_model->getAnimationMode();
@@ -402,11 +432,13 @@ bool AnimWidget::copyFrame( bool selected )
       copy.z = 0;
       copy.isRotation = false;
 
+      bool loop = m_model->getAnimLooping( Model::ANIMMODE_SKELETAL, m_currentAnim );
+
       for ( j = 0; j < numJoints; j++ )
       {
          if ( !selected || m_model->isBoneJointSelected(j) )
          {
-            if ( m_model->getSkelAnimKeyframe( m_currentAnim, m_currentFrame, j, false, copy.x, copy.y, copy.z ) )
+            if ( m_model->interpSkelAnimKeyframe( m_currentAnim, m_currentFrame, loop, j, false, copy.x, copy.y, copy.z ) )
             {
                copy.joint = j;
                copy.isRotation = false;
@@ -420,7 +452,7 @@ bool AnimWidget::copyFrame( bool selected )
       {
          if ( !selected || m_model->isBoneJointSelected(j) )
          {
-            if ( m_model->getSkelAnimKeyframe( m_currentAnim, m_currentFrame, j, true, copy.x, copy.y, copy.z ) )
+            if ( m_model->interpSkelAnimKeyframe( m_currentAnim, m_currentFrame, loop, j, true, copy.x, copy.y, copy.z ) )
             {
                copy.joint = j;
                copy.isRotation = true;
@@ -447,23 +479,32 @@ void AnimWidget::pasteFrame()
          return;
       }
 
+      m_model->unselectAll();
+      m_model->beginSelectionDifference();
+
       FrameCopyList::iterator it;
       FramePointCopyList::iterator pit;
 
       for ( it = m_frameCopyList.begin(); it != m_frameCopyList.end(); it++ )
       {
+         m_model->selectVertex( (*it).vertex );
+
          m_model->setFrameAnimVertexCoords( m_currentAnim, m_currentFrame, (*it).vertex,
                (*it).x, (*it).y, (*it).z );
       }
 
       for ( pit = m_framePointCopyList.begin(); pit != m_framePointCopyList.end(); pit++ )
       {
+         m_model->selectPoint( (*pit).point );
+
          m_model->setFrameAnimPointCoords( m_currentAnim, m_currentFrame, (*pit).point,
                (*pit).x, (*pit).y, (*pit).z );
          m_model->setFrameAnimPointRotation( m_currentAnim, m_currentFrame, (*pit).point,
                (*pit).rx, (*pit).ry, (*pit).rz );
       }
 
+      m_model->endSelectionDifference();
+
       m_model->operationComplete( tr( "Paste frame", "paste frame animation position, operation complete" ).toUtf8() );
 
       m_model->setCurrentAnimationFrame( m_currentFrame );
@@ -478,11 +519,29 @@ void AnimWidget::pasteFrame()
          return;
       }
 
+      m_model->unselectAll();
+      m_model->beginSelectionDifference();
+
+      bool loop = m_model->getAnimLooping( Model::ANIMMODE_SKELETAL, m_currentAnim );
+
       for ( it = m_keyframeCopyList.begin(); it != m_keyframeCopyList.end(); it++ )
       {
-         m_model->setSkelAnimKeyframe( m_currentAnim, m_currentFrame, (*it).joint, (*it).isRotation,
-               (*it).x, (*it).y, (*it).z );
+         double pasteVec[3] = { (*it).x, (*it).y, (*it).z };
+         double currentVec[3];
+
+         m_model->interpSkelAnimKeyframe( m_currentAnim, m_currentFrame, loop, (*it).joint, (*it).isRotation, currentVec[0], currentVec[1], currentVec[2] );
+
+         if ( !floatCompareVector( currentVec, pasteVec, 3 ) )
+         {
+            m_model->selectBoneJoint( (*it).joint );
+
+            m_model->setSkelAnimKeyframe( m_currentAnim, m_currentFrame, (*it).joint, (*it).isRotation,
+                  (*it).x, (*it).y, (*it).z );
+         }
       }
+
+      m_model->endSelectionDifference();
+
       m_model->operationComplete( tr( "Paste keyframe", "Paste keyframe animation data complete" ).toUtf8() );
 
       m_model->setCurrentAnimationFrame( m_currentFrame );  // Force refresh of joints
