@@ -1,4 +1,4 @@
-/*  Misfit Model 3D
+/*  Maverick Model 3D
  * 
  *  Copyright (c) 2004-2007 Kevin Worcester
  * 
@@ -30,11 +30,11 @@
 #include "textureframe.h"
 #include "helpwin.h"
 
-#include <QtGui/QPushButton>
-#include <QtGui/QLayout>
-#include <QtGui/QTabWidget>
-#include <QtGui/QHBoxLayout>
-#include <QtGui/QShortcut>
+#include <QtWidgets/QPushButton>
+#include <QtWidgets/QLayout>
+#include <QtWidgets/QTabWidget>
+#include <QtWidgets/QHBoxLayout>
+#include <QtWidgets/QShortcut>
 
 #include <stdlib.h>
 
@@ -71,7 +71,7 @@ void BackgroundWin::helpNowEvent()
    win->show();
 }
 
-void BackgroundWin::selectedPageEvent( const QString & str )
+void BackgroundWin::selectedPageEvent( int index )
 {
    QWidget * widget = m_tabs->currentWidget();
    widget->repaint();
