@@ -1,4 +1,4 @@
-/*  Misfit Model 3D
+/*  Maverick Model 3D
  * 
  *  Copyright (c) 2004-2007 Kevin Worcester
  * 
@@ -26,7 +26,7 @@
 
 #include "backgroundwin.base.h"
 
-#include <QtGui/QDialog>
+#include <QtWidgets/QDialog>
 
 class Model;
 class BackgroundSelect;
@@ -40,7 +40,7 @@ class BackgroundWin : public QDialog, public Ui::BackgroundWinBase
       virtual ~BackgroundWin();
 
    public slots:
-      void selectedPageEvent( const QString & str );
+      void selectedPageEvent( int index );
       void accept();
       void reject();
 
