@@ -1,4 +1,4 @@
-/*  Misfit Model 3D
+/*  Maverick Model 3D
  * 
  *  Copyright (c) 2004-2007 Kevin Worcester
  * 
@@ -26,7 +26,7 @@
 
 #include "contextprojection.base.h"
 
-#include <QtGui/QWidget>
+#include <QtWidgets/QWidget>
 
 #include "contextwidget.h"
 
