@@ -30,9 +30,10 @@
 #include <QtCore/QtGlobal>
 #include <QtCore/QLocale>
 #include <QtCore/QTranslator>
+#include <QtCore/QLibraryInfo>
 #include <QtWidgets/QApplication>
 #include <QtGui/QFileOpenEvent>
-#include <QtOpenGL/QGLFormat>
+#include <QtGui/QSurfaceFormat>
 
 #include <list>
 #include <string>
@@ -75,29 +76,6 @@ static ModelApp     * s_app = NULL;
 static QTranslator  * s_qtXlat = NULL;
 static QTranslator  * s_mm3dXlat = NULL;
 
-static bool _has_gl_support()
-{
-   if ( ! QGLFormat::hasOpenGL() )
-   {
-      log_error( "No openGL support, exiting...\n" );
-      return false;
-   }
-
-   QGLFormat format = QGLFormat::defaultFormat();
-
-   format.setDoubleBuffer( true );
-   format.setRgba( true );
-   format.setAlpha( true );
-
-   QGLFormat::setDefaultFormat( format );
-
-   format = QGLFormat::defaultFormat();
-
-   log_debug( "qt says alpha is%s enabled\n", (format.alpha() ? "" : " not" ) );
-
-   return true;
-}
-
 static void _cleanup()
 {
    // TODO add any necessary cleanup
@@ -108,14 +86,15 @@ static bool loadTranslationFile( QTranslator * xlat, const QString & localeFile
    std::list<std::string> path_list;
 
    path_list.push_back( "." );
-   path_list.push_back( "../i18n" );
-   path_list.push_back( getI18nDirectory() );
+   path_list.push_back( "../translations" );
+   path_list.push_back( getTranslationsDirectory() );
+   path_list.push_back( QLibraryInfo::location( QLibraryInfo::TranslationsPath ).toUtf8().data() );
 
    // try current directory first (for override), then mm3d system directory
    for ( std::list<std::string>::iterator it = path_list.begin(); it != path_list.end(); ++it )
    {
       log_debug( "attempting to load translation %s from %s\n", (const char *) localeFile.toUtf8(), (const char *) it->c_str() );
-      if ( s_qtXlat->load( localeFile, it->c_str() ) )
+      if ( xlat->load( localeFile, it->c_str() ) )
       {
          log_debug( "  loaded.\n" );
          return true;
@@ -152,6 +131,13 @@ int ui_prep( int & argc, char * argv[] )
    s_app->setAttribute( Qt::AA_DontUseNativeMenuBar );
 #endif
 
+   // Set default format for QOpenGLWidget.
+   QSurfaceFormat format = QSurfaceFormat::defaultFormat();
+   format.setRenderableType( QSurfaceFormat::OpenGL );
+   format.setVersion( 1, 2 );
+   format.setSwapBehavior( QSurfaceFormat::DoubleBuffer );
+   QSurfaceFormat::setDefaultFormat( format );
+
    QString loc = mlocale_get().c_str();
 
    if ( loc == "" )
@@ -189,11 +175,6 @@ int ui_init( int & argc, char * argv[] )
    }
    if ( cmdline_runui )
    {
-      if ( ! _has_gl_support() )
-      {
-         return -1;
-      }
-
       bool opened = false;
       unsigned openCount = 0;
 
