@@ -143,8 +143,8 @@ void CommandWidget::activateCommand( bool )
 {
    if ( !(*m_canEdit) )
    {
-      model_status( m_model, StatusError, STATUSTIME_LONG,
-            tr("You are in animation mode, but there are no animations").toUtf8() );
+      model_status( m_model, StatusError, STATUSTIME_LONG, "%s",
+            tr("You are in animation mode, but there are no animations").toUtf8().data() );
       return;
    }
 
@@ -671,10 +671,15 @@ ViewWindow::ViewWindow( Model * model, QWidget * parent )
    m_animMenu->addSeparator();
    m_animSetRotItem    = m_animMenu->addAction( tr("Set Rotation Keyframe", "Animation|Set Rotation Keyframe"), this, SLOT(animSetRotEvent()), g_keyConfig.getKey( "viewwin_anim_set_rotation" ) );
    m_animSetTransItem  = m_animMenu->addAction( tr("Set Translation Keyframe", "Animation|Set Translation Keyframe"), this, SLOT(animSetTransEvent()), g_keyConfig.getKey( "viewwin_anim_set_translation" ) );
+   m_animClearRotItem    = m_animMenu->addAction( tr("Clear Rotation Keyframe", "Animation|Clear Rotation Keyframe"), this, SLOT(animClearRotEvent()), g_keyConfig.getKey( "viewwin_anim_clear_rotation" ) );
+   m_animClearTransItem  = m_animMenu->addAction( tr("Clear Translation Keyframe", "Animation|Clear Translation Keyframe"), this, SLOT(animClearTransEvent()), g_keyConfig.getKey( "viewwin_anim_clear_translation" ) );
+
 
    m_stopAnimItem->setEnabled( false );
    m_animSetRotItem->setEnabled( false );
    m_animSetTransItem->setEnabled( false );
+   m_animClearRotItem->setEnabled( false );
+   m_animClearTransItem->setEnabled( false );
 
    m_animCopyFrame->setEnabled( false );
    m_animPasteFrame->setEnabled( false );
@@ -770,7 +775,7 @@ ViewWindow::~ViewWindow()
    log_debug( "deleting view window\n" );
    _winList.remove( this );
 
-   log_debug( "deleting view window %08X, model %08X\n", this, m_model );
+   log_debug( "deleting view window %p, model %p\n", this, m_model );
    DecalManager::getInstance()->unregisterModel( m_model );
    m_viewPanel->freeTextures();
    delete m_model;
@@ -965,7 +970,7 @@ void ViewWindow::exportSelectedEvent()
          && m_model->getSelectedPointCount() == 0
          && m_model->getSelectedProjectionCount() == 0 )
    {
-      model_status( m_model, StatusError, STATUSTIME_LONG, tr( "You must have at least 1 face, joint, or point selected to Export Selected" ).toUtf8() );
+      model_status( m_model, StatusError, STATUSTIME_LONG, "%s", tr( "You must have at least 1 face, joint, or point selected to Export Selected" ).toUtf8().data() );
       return;
    }
 
@@ -1140,7 +1145,7 @@ void ViewWindow::mergeModelsEvent()
       {
          model_show_alloc_stats();
 
-         MergeWindow mw( model, this );
+         MergeWindow mw( model, m_model, this );
 
          if ( mw.exec() )
          {
@@ -1159,7 +1164,7 @@ void ViewWindow::mergeModelsEvent()
             double trans[3];
             mw.getRotation( rot );
             mw.getTranslation( trans );
-            m_model->mergeModels( model, mw.getIncludeTexture(), mode, true, trans, rot );
+            m_model->mergeModels( model, mw.getIncludeTexture(), mode, true, mw.getPoint(), trans, rot );
             m_model->operationComplete( tr("Merge models").toUtf8() );
             g_prefs( "ui_model_dir" ) = (const char *) d.directory().absolutePath().toUtf8();
 
@@ -1230,6 +1235,7 @@ void ViewWindow::mergeAnimationsEvent()
          model_show_alloc_stats();
 
          m_model->mergeAnimations( model );
+         m_model->operationComplete( tr("Merge animations").toUtf8() );
 
          prefs_recent_model( filename.c_str() );
          delete model;
@@ -1420,7 +1426,7 @@ QAction * ViewWindow::insertMenuItem( QMenu * parentMenu, bool isTool,
    {
       id = addMenu->addAction( name );
    }
-   log_debug( "added %s as id %d\n", (const char *) name.toUtf8(), id );
+   log_debug( "added %s as id %p\n", (const char *) name.toUtf8(), id );
    return id;
 }
 
@@ -1735,7 +1741,7 @@ void ViewWindow::undoRequest()
    }
    else
    {
-      model_status( m_model, StatusNormal, STATUSTIME_SHORT, tr("Nothing to undo").toUtf8() );
+      model_status( m_model, StatusNormal, STATUSTIME_SHORT, "%s", tr("Nothing to undo").toUtf8().data() );
    }
 }
 
@@ -1780,13 +1786,13 @@ void ViewWindow::redoRequest()
    }
    else
    {
-      model_status( m_model, StatusNormal, STATUSTIME_SHORT, tr("Nothing to redo").toUtf8() );
+      model_status( m_model, StatusNormal, STATUSTIME_SHORT, "%s", tr("Nothing to redo").toUtf8().data() );
    }
 }
 
 void ViewWindow::snapToSelectedEvent( QAction * snapTo )
 {
-   log_debug( "snapToSelectedEvent( %d )\n", snapTo );
+   log_debug( "snapToSelectedEvent( %p )\n", snapTo );
    g_prefs( "ui_snap_grid" )   = ( m_snapToGrid->isChecked() ) ? 1 : 0;
    g_prefs( "ui_snap_vertex" ) = ( m_snapToVertex->isChecked() ) ? 1 : 0;
 }
@@ -1851,6 +1857,42 @@ void ViewWindow::animSetTransEvent()
    m_model->operationComplete( tr("Set translation keframe").toUtf8() );
 }
 
+void ViewWindow::animClearRotEvent()
+{
+   if ( m_model->getAnimationMode() == Model::ANIMMODE_SKELETAL )
+   {
+      bool isRotation = true;
+      list<int> joints;
+      m_model->getSelectedBoneJoints( joints );
+      for ( list<int>::iterator it = joints.begin(); it != joints.end(); it++ )
+      {
+         m_model->deleteSkelAnimKeyframe( m_model->getCurrentAnimation(),
+                                          m_model->getCurrentAnimationFrame(),
+                                          *it, isRotation );
+      }
+   }
+
+   m_model->operationComplete( tr("Clear rotation keframe").toUtf8() );
+}
+
+void ViewWindow::animClearTransEvent()
+{
+   if ( m_model->getAnimationMode() == Model::ANIMMODE_SKELETAL )
+   {
+      bool isRotation = false;
+      list<int> joints;
+      m_model->getSelectedBoneJoints( joints );
+      for ( list<int>::iterator it = joints.begin(); it != joints.end(); it++ )
+      {
+         m_model->deleteSkelAnimKeyframe( m_model->getCurrentAnimation(),
+                                          m_model->getCurrentAnimationFrame(),
+                                          *it, isRotation );
+      }
+   }
+
+   m_model->operationComplete( tr("Clear translation keframe").toUtf8() );
+}
+
 void ViewWindow::animCopyFrameEvent()
 {
    if ( m_animWin->isVisible() )
@@ -1921,6 +1963,8 @@ void ViewWindow::animationModeOn()
    m_stopAnimItem->setEnabled(  true  );
    m_animSetRotItem->setEnabled(  true  );
    m_animSetTransItem->setEnabled(  true  );
+   m_animClearRotItem->setEnabled(  true  );
+   m_animClearTransItem->setEnabled(  true  );
    m_animCopyFrame->setEnabled(  true  );
    m_animPasteFrame->setEnabled(  false  ); // Disabled until copy occurs
    m_animClearFrame->setEnabled(  true  );
@@ -1938,6 +1982,8 @@ void ViewWindow::animationModeOff()
    m_stopAnimItem->setEnabled(  false  );
    m_animSetRotItem->setEnabled(  false  );
    m_animSetTransItem->setEnabled(  false  );
+   m_animClearRotItem->setEnabled(  false  );
+   m_animClearTransItem->setEnabled(  false  );
    m_animCopyFrame->setEnabled(  false  );
    m_animPasteFrame->setEnabled(  false  );
    m_animClearFrame->setEnabled(  false  );
