@@ -539,7 +539,7 @@ Model::ModelErrorE Cal3dFilter::readSubFile( const char * filename )
       errStr += ": ";
       errStr += Model::errorToString( err );
 
-      model_status( m_model, StatusError, STATUSTIME_LONG, errStr.c_str() );
+      model_status( m_model, StatusError, STATUSTIME_LONG, "%s", errStr.c_str() );
    }
 
    return err;
@@ -1558,7 +1558,7 @@ bool Cal3dFilter::readBCompressedAnimTrack( double duration )
       uint32_t trans_comp = readBInt32();
       uint64_t rot_comp = readBUInt48();
 
-      log_debug( "compressed trans = %X  rot = %llX\n",
+      log_debug( "compressed trans = %x  rot = %" PRIx64 "\n",
          trans_comp, rot_comp );
 
       Vector trans;
