@@ -25,6 +25,8 @@
 
 #include "config.h"
 
+#define GL_GLEXT_LEGACY
+
 #ifdef IS_OSX
 #include <OpenGL/gl.h>
 #include <OpenGL/glu.h>
@@ -33,4 +35,9 @@
 #include <GL/glu.h>
 #endif //
 
+// OpenGL 1.2
+#ifndef GL_CLAMP_TO_EDGE
+#define GL_CLAMP_TO_EDGE 0x812F
+#endif
+
 #endif // __GLHEADERS_H
