@@ -24,6 +24,8 @@
 #ifndef __LOG_H
 #define __LOG_H
 
+#include "mm3dport.h"
+
 #ifdef __DO_PROFILE
 
 #include <stdio.h>
@@ -81,8 +83,8 @@ extern void log_enable_debug( bool o );
 extern void log_enable_warning( bool o );
 extern void log_enable_error( bool o );
 
-extern void log_debug( const char * fmt, ... );
-extern void log_warning( const char * fmt, ... );
-extern void log_error( const char * fmt, ... );
+extern void log_debug( const char * fmt, ... ) __attribute__ ((format (printf, 1, 2)));
+extern void log_warning( const char * fmt, ... ) __attribute__ ((format (printf, 1, 2)));
+extern void log_error( const char * fmt, ... ) __attribute__ ((format (printf, 1, 2)));
 
 #endif // __LOG_H
