@@ -1,7 +1,7 @@
 /*  Md3Filter plugin for Maverick Model 3D
  *
  *  Copyright (c) 2005-2007 Russell Valentine and Kevin Worcester
- *  Copyright (c) 2009-2015 Zack Middleton
+ *  Copyright (c) 2009-2020 Zack Middleton
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -42,6 +42,7 @@
 #include "mm3dport.h"
 #include "datadest.h"
 #include "datasource.h"
+#include "release_ptr.h"
 #include "msg.h"
 
 #include "translate.h"
@@ -108,6 +109,88 @@ const char *s_animSyncWarning[] =
    NULL
 };
 
+Md3Filter::Md3Options::Md3Options()
+   : m_playerSupported( false ),
+     m_saveAsPlayer( false ),
+     m_saveAnimationCfg( false )
+{
+}
+
+Md3Filter::Md3Options::~Md3Options()
+{
+}
+
+void Md3Filter::Md3Options::setOptionsFromModel( Model * model, const char * const filename )
+{
+   m_playerSupported = false;
+
+   string modelPath = "";
+   string modelBaseName = "";
+   string modelFullName = "";
+
+   normalizePath( filename, modelFullName, modelPath, modelBaseName );
+
+   if (     strncasecmp( modelBaseName.c_str(), "lower.", 6 ) == 0
+         || strncasecmp( modelBaseName.c_str(), "upper.", 6 ) == 0
+         || strncasecmp( modelBaseName.c_str(), "head.",  5 ) == 0 )
+   {
+      bool haveUpper = false;
+      bool haveLower = false;
+      bool haveUnknown = false;
+
+      unsigned gcount = model->getGroupCount();
+      for ( unsigned g = 0; g < gcount; g++ )
+      {
+         std::string name = model->getGroupName( g );
+         if ( name[0] != '\0' && name[1] == '_' )
+         {
+            switch ( toupper( name[0] ) )
+            {
+               case 'U':
+                  haveUpper = true;
+                  break;
+               case 'L':
+                  haveLower = true;
+                  break;
+               case 'H':
+                  break;
+               default:
+                  haveUnknown = true;
+                  break;
+            }
+         } else {
+            haveUnknown = true;
+         }
+      }
+
+      if ( !haveUnknown && haveUpper && haveLower
+            && model->getPointByName( "tag_torso" ) >= 0
+            && model->getPointByName( "tag_head" )  >= 0 )
+      {
+         // have filename, groups, and tags required for player model
+         m_playerSupported = true;
+      }
+   }
+
+   m_saveAsPlayer = m_playerSupported;
+   m_saveAnimationCfg = m_playerSupported;
+
+   char value[20];
+   if ( model->getMetaData( "MD3_composite", value, sizeof( value ) ) )
+   {
+      if ( atoi( value ) == 0 )
+      {
+         m_saveAsPlayer = false;
+         m_saveAnimationCfg = false;
+      }
+   }
+
+   if ( model->getMetaData( "MD3_animationcfg", value, sizeof( value ) ) )
+   {
+      m_saveAnimationCfg = !!atoi( value );
+   }
+}
+
 Md3Filter::Md3Filter()
 {
 }
@@ -291,7 +374,7 @@ Model::ModelErrorE Md3Filter::readFile( Model * model, const char * const filena
          log_debug( "Offset Tags: %d\n",  offsetTags );
          log_debug( "Offset Meshes: %d\n",  offsetMeshes );
          log_debug( "Offset End: %d\n",        offsetEnd );
-         log_debug( "File Length: %d\n",       m_src->getFileSize() );
+         log_debug( "File Length: %" PORTuSIZE "\n",       m_src->getFileSize() );
 
          if ( magic[0] != 'I' && magic[1] != 'D' && magic[2] != 'P' && magic[3] != '3' )
          {
@@ -740,7 +823,7 @@ bool Md3Filter::readAnimations( bool create )
                   char *name = NULL;
                   std::string str;
 
-                  // Save settings "name value" into MD3_CGF_(name)
+                  // Save settings "name value" into MD3_CFG_(name)
 
                   name = line;
                   while( isspace(name[0]) )
@@ -1703,10 +1786,18 @@ std::string Md3Filter::getSafeName( unsigned int anim )
    return animName;
 }
  
-Model::ModelErrorE Md3Filter::writeFile( Model * model, const char * const filename, ModelFilter::Options *  )
+Model::ModelErrorE Md3Filter::writeFile( Model * model, const char * const filename, ModelFilter::Options * o )
 {
    if ( model && filename && filename[0] )
    {
+      release_ptr<Md3Options> freeOptions = NULL;
+      m_options = dynamic_cast<Md3Options *>( o );
+      if ( !m_options )
+      {
+         freeOptions = static_cast< Md3Options * >( getDefaultOptions() );
+         m_options = freeOptions.get();
+      }
+
       unsigned tcount = model->getTriangleCount();
       for ( unsigned t = 0; t < tcount; ++t )
       {
@@ -1725,7 +1816,12 @@ Model::ModelErrorE Md3Filter::writeFile( Model * model, const char * const filen
       // coordinate or normal. MM3D does. The mesh_create_list function will
       // break the model up into meshes where vertices meet the MD3 criteria.
       // See mesh.h for details.
+#if 0
+      // TODO: Split up meshes to meet Quake 3 per-mesh triangle and vertex limits. Need an export option dialog and/or meta data.
+      mesh_create_list( meshes, model, Mesh::MO_All, 2000 - 1, 1000 - 1 );
+#else
       mesh_create_list( meshes, model );
+#endif
 
       string modelPath = "";
       string modelBaseName = "";
@@ -1735,88 +1831,7 @@ Model::ModelErrorE Md3Filter::writeFile( Model * model, const char * const filen
 
       m_modelPath = modelPath;
 
-      bool saveAsPlayer = true;
-
-      bool haveUpper = false;
-      bool haveLower = false;
-
-      unsigned gcount = m_model->getGroupCount();
-      for ( unsigned g = 0; g < gcount; g++ )
-      {
-         std::string name = m_model->getGroupName( g );
-         if ( name[1] == '_' )
-         {
-            switch ( toupper( name[0] ) )
-            {
-               case 'U':
-                  haveUpper = true;
-                  break;
-               case 'L':
-                  haveLower = true;
-                  break;
-               default:
-                  break;
-            }
-         }
-      }
-
-      if ( haveUpper && haveLower )
-      {
-         if (  m_model->getPointByName( "tag_torso" )  < 0
-            || m_model->getPointByName( "tag_head" )   < 0 )
-         {
-            // missing required tags for player model
-            saveAsPlayer = false;
-         }
-      }
-      else
-      {
-         // don't have the proper groups to save as a player model
-         saveAsPlayer = false;
-      }
-
-      if ( saveAsPlayer )
-      {
-         if (     strncasecmp( modelBaseName.c_str(), "lower.", 6 ) == 0 
-               || strncasecmp( modelBaseName.c_str(), "upper.", 6 ) == 0 
-               || strncasecmp( modelBaseName.c_str(), "head.",  5 ) == 0 )
-         {
-            log_debug( "filename %s looks like a player model\n", modelBaseName.c_str() );
-            char value[20];
-            if ( model->getMetaData( "MD3_composite", value, sizeof( value ) ) )
-            {
-               if ( atoi( value ) == 0 )
-               {
-                  log_debug( "model is explicitly not a composite\n" );
-                  saveAsPlayer = false;
-               }
-            }
-            else
-            {
-               char answer = msg_info_prompt( transll( QT_TRANSLATE_NOOP( "LowLevel", "This looks like a player model.\nDo you want to save all sections?")).c_str(), "Ync" );
-               if ( answer == 'Y' )
-               {
-                  model->addMetaData( "MD3_composite", "1" );
-               }
-               else if ( answer == 'N' )
-               {
-                  model->addMetaData( "MD3_composite", "0" );
-                  saveAsPlayer = false;
-               }
-               else
-               {
-                  return Model::ERROR_CANCEL;
-               }
-            }
-         }
-         else
-         {
-            log_debug( "filename %s does not look like a player model\n", modelBaseName.c_str() );
-            saveAsPlayer = false;
-         }
-      }
-
-      if ( saveAsPlayer )
+      if ( m_options->m_saveAsPlayer )
       {
          log_debug( "saving as a player model\n" );
 
@@ -1831,8 +1846,16 @@ Model::ModelErrorE Md3Filter::writeFile( Model * model, const char * const filen
          playerFile = path + fixFileCase( m_modelPath.c_str(), "head.md3" );
          writeSectionFile( playerFile.c_str(), MS_Head,  meshes );
 
-         writeAnimations();
+         if ( m_options->m_saveAnimationCfg )
+         {
+            writeAnimations( true, NULL );
+         }
+         else
+         {
+            model->addMetaData( "MD3_animationcfg", "0" );
+         }
 
+         model->addMetaData( "MD3_composite", "1" );
          model->operationComplete( transll( QT_TRANSLATE_NOOP( "LowLevel", "Set meta data for MD3 export" ) ).c_str() );
 
          return Model::ERROR_NONE;
@@ -1840,7 +1863,29 @@ Model::ModelErrorE Md3Filter::writeFile( Model * model, const char * const filen
       else
       {
          log_debug( "saving as a single model\n" );
-         return writeSectionFile( filename, MS_None, meshes );
+
+         writeSectionFile( filename, MS_None, meshes );
+
+         if ( m_options->m_saveAnimationCfg )
+         {
+            writeAnimations( false, filename );
+         }
+
+         if ( m_options->m_saveAnimationCfg || m_options->m_playerSupported )
+         {
+            if ( m_options->m_playerSupported )
+            {
+               model->addMetaData( "MD3_composite", "0" );
+            }
+            if ( m_options->m_saveAnimationCfg )
+            {
+               model->addMetaData( "MD3_animationcfg", "1" );
+            }
+
+            model->operationComplete( transll( QT_TRANSLATE_NOOP( "LowLevel", "Set meta data for MD3 export" ) ).c_str() );
+         }
+
+         return Model::ERROR_NONE;
       }
    }
    else
@@ -2009,7 +2054,7 @@ Model::ModelErrorE Md3Filter::writeSectionFile( const char * filename, Md3Filter
    }
 
    // FRAMES
-   log_debug( "writing frames at %d/%d\n", offsetFrames, m_dst->offset() );
+   log_debug( "writing frames at %d/%d\n", offsetFrames, (int)m_dst->offset() );
    unsigned a;
 
    for ( a = 0; a < animCount; a++ )
@@ -2108,7 +2153,7 @@ Model::ModelErrorE Md3Filter::writeSectionFile( const char * filename, Md3Filter
    m_model->setNoAnimation();
 
    //TAGS
-   log_debug( "writing tags at %d/%d\n", offsetTags, m_dst->offset() );
+   log_debug( "writing tags at %d/%d\n", offsetTags, (int)m_dst->offset() );
 
    for ( a = 0; a < animCount; a++ )
    {
@@ -2202,7 +2247,7 @@ Model::ModelErrorE Md3Filter::writeSectionFile( const char * filename, Md3Filter
    vector<Model::Material *> & modelMaterials = getMaterialList( m_model );
 
    // MESHES
-   log_debug( "writing meshes at %d/%d\n", offsetMeshes, m_dst->offset() );
+   log_debug( "writing meshes at %d/%d\n", offsetMeshes, (int)m_dst->offset() );
 
    for ( mlit = meshes.begin(); mlit != meshes.end(); mlit++ )
    {
@@ -2469,7 +2514,7 @@ bool Md3Filter::animSyncWarning(std::string name)
    return false;
 }
 
-bool Md3Filter::writeAnimations()
+bool Md3Filter::writeAnimations( bool playerModel, const char * modelName )
 {
    string animFile = m_modelPath + "/animation.cfg";
    bool eliteLoop = false;
@@ -2487,7 +2532,14 @@ bool Md3Filter::writeAnimations()
    {
       log_debug( "writing animation.cfg\n" );
 
-      dst->writeString( "// animation config file\r\n" );
+      if ( modelName )
+      {
+         dst->writePrintf( "// animation config file for %s\r\n", PORT_basename( modelName ) );
+      }
+      else
+      {
+         dst->writeString( "// animation config file\r\n" );
+      }
 
       bool hadKeyword = false;
       char keyword[1024], value[1024];
@@ -2560,7 +2612,7 @@ bool Md3Filter::writeAnimations()
          int animFrame = 0;
          int count = 1;
          int fps   = 15;
-         if (!getExportAnimData( (int)anim, animFrame, count, fps ))
+         if (!getExportAnimData( playerModel, (int)anim, animFrame, count, fps ))
          {
             continue;
          }
@@ -2649,10 +2701,15 @@ Matrix Md3Filter::getMatrixFromPoint( int anim, int frame, int point )
    return m;
 }
 
-Md3Filter::MeshAnimationTypeE Md3Filter::getAnimationType(const std::string animName)
+Md3Filter::MeshAnimationTypeE Md3Filter::getAnimationType( bool playerModel, const std::string & animName )
 {
    MeshAnimationTypeE animType = MA_All;
 
+   if ( !playerModel )
+   {
+      return MA_All;
+   }
+
    if (strncasecmp(animName.c_str(), "both_", 5) == 0)
    {
       animType = MA_Both;
@@ -2673,7 +2730,7 @@ Md3Filter::MeshAnimationTypeE Md3Filter::getAnimationType(const std::string anim
    return animType;
 }
 
-bool Md3Filter::getExportAnimData( int modelAnim,
+bool Md3Filter::getExportAnimData( bool playerModel, int modelAnim,
       int & fileFrame, int & frameCount, int & fps )
 {
    fileFrame  = 0;
@@ -2681,7 +2738,7 @@ bool Md3Filter::getExportAnimData( int modelAnim,
 
    size_t animCount = m_model->getAnimCount( Model::ANIMMODE_FRAME );
    std::string animName = getSafeName( modelAnim );
-   MeshAnimationTypeE animType = getAnimationType(animName);
+   MeshAnimationTypeE animType = getAnimationType( playerModel, animName );
 
    // If this is a "dead" animation and its after a "death" animation
    //   and it has 0 frames, use the last frame of the death animation.
@@ -2691,7 +2748,7 @@ bool Md3Filter::getExportAnimData( int modelAnim,
          && strncasecmp(getSafeName( modelAnim - 1 ).c_str(), "both_death", 10) == 0))
       && m_model->getAnimFrameCount( Model::ANIMMODE_FRAME, modelAnim ) == 0 )
    {
-      if (getExportAnimData( modelAnim - 1, fileFrame, frameCount, fps ))
+      if ( getExportAnimData( playerModel, modelAnim - 1, fileFrame, frameCount, fps ) )
       {
          fileFrame += frameCount - 1;
          frameCount = 1;
@@ -2702,11 +2759,12 @@ bool Md3Filter::getExportAnimData( int modelAnim,
    for ( size_t a = 0; a < animCount; a++ )
    {
       std::string name = getSafeName( a );
-      if ( animInSection( name, MS_Upper )
+      if ( !playerModel
+            || animInSection( name, MS_Upper )
             || animInSection( name, MS_Lower )
-            || animInSection( name, MS_Head ))
+            || animInSection( name, MS_Head ) )
       {
-         MeshAnimationTypeE type = getAnimationType(name);
+         MeshAnimationTypeE type = getAnimationType( playerModel, name );
          if ( (int)a == modelAnim )
          {
             frameCount = m_model->getAnimFrameCount( Model::ANIMMODE_FRAME, a );
@@ -2727,7 +2785,7 @@ bool Md3Filter::getExportAnimData( int modelAnim,
                return true;
             }
          }
-         // All torso frames go before leg frames, all legs go after tosro
+         // All torso frames go before leg frames, all legs go after torso
          else if (((int)a < modelAnim && animType >= type) || ((int)a > modelAnim && animType > type))
          {
                fileFrame += m_model->getAnimFrameCount( Model::ANIMMODE_FRAME, a );
