@@ -1,7 +1,7 @@
 /*  Md3Filter plugin for Maverick Model 3D
  *
  *  Copyright (c) 2005-2007 Russell Valentine and Kevin Worcester
- *  Copyright (c) 2009-2015 Zack Middleton
+ *  Copyright (c) 2009-2020 Zack Middleton
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -57,6 +57,27 @@ class DataSource;
 class Md3Filter : public ModelFilter
 {
    public:
+
+      class Md3Options : public ModelFilter::Options
+      {
+         public:
+            Md3Options();
+
+            virtual void release() { delete this; };
+
+            bool m_playerSupported;
+
+            bool m_saveAsPlayer;
+            bool m_saveAnimationCfg;
+
+            void setOptionsFromModel( Model * m, const char * const filename );
+
+         protected:
+            virtual ~Md3Options(); // Use release() instead
+      };
+
+      ModelFilter::Options * getDefaultOptions() { return new Md3Options; };
+
       Md3Filter();
       virtual ~Md3Filter();
 
@@ -179,8 +200,9 @@ class Md3Filter : public ModelFilter
 
       //writes
       Model::ModelErrorE writeSectionFile( const char * filename, MeshSectionE section, MeshList & meshes );
-      bool     writeAnimations();
+      bool     writeAnimations( bool playerModel, const char * filename );
       DataDest * m_dst;
+      Md3Options * m_options;
 
       //writes util
       bool     animSyncWarning(std::string name);
@@ -188,8 +210,8 @@ class Md3Filter : public ModelFilter
       double   greater(double a, double b);
       double   smaller(double a, double b);
       Matrix   getMatrixFromPoint( int anim, int frame, int point );
-      MeshAnimationTypeE getAnimationType(const std::string animName);
-      bool getExportAnimData( int modelAnim,
+      MeshAnimationTypeE getAnimationType( bool playerModel, const std::string & animName );
+      bool getExportAnimData( bool playerModel, int modelAnim,
             int & fileFrame, int & frameCount, int & fps );
 };
 #endif // __MD3FILTER_H
