@@ -20,6 +20,7 @@
  *  See the COPYING file for full license text.
  */
 
+#include <algorithm>
 
 #include "mm3dfilter.h"
 
@@ -1070,6 +1071,7 @@ Model::ModelErrorE MisfitFilter::readFile( Model * model, const char * const fil
    {
       bool     variable = _offsetIsVariable( MDT_ExtTextures, offsetList );
       uint32_t offset   = _offsetGet( MDT_ExtTextures, offsetList );
+      uint32_t texcoordsOffset = _offsetGet( MDT_TexCoords, offsetList );
 
       m_src->seek(offset);
 
@@ -1086,6 +1088,14 @@ Model::ModelErrorE MisfitFilter::readFile( Model * model, const char * const fil
 
       for ( unsigned t = 0; t < count; t++ )
       {
+         // Before Maverick Model 3D 1.3.13, MM3D wrote external texture count as material count.
+         // It may be higher than the number of textures written to the file.
+         if ( texcoordsOffset >= offset && m_src->offset() >= texcoordsOffset )
+         {
+            log_debug( "invalid external texture count (should be %d instead of %d)\n", t, count );
+            break;
+         }
+
          log_debug( "reading external texture %d/%d\n", t, count );
          if ( variable )
          {
@@ -1181,7 +1191,7 @@ Model::ModelErrorE MisfitFilter::readFile( Model * model, const char * const fil
                memset( mat->m_color, 255, sizeof( mat->m_color ) );
                break;
             default:
-               log_debug( "  got unknown material type\n", texIndex );
+               log_debug( "  got unknown material type %d\n", flags & 0x0f );
                mat->m_type = Model::Material::MATTYPE_BLANK;
                mat->m_filename = "";
                memset( mat->m_color, 255, sizeof( mat->m_color ) );
@@ -1498,7 +1508,7 @@ Model::ModelErrorE MisfitFilter::readFile( Model * model, const char * const fil
          }
       }
 
-      log_debug( "read %d points\n" );
+      log_debug( "read %d points\n", count );
    }
 
    // Smooth Angles
@@ -1569,7 +1579,7 @@ Model::ModelErrorE MisfitFilter::readFile( Model * model, const char * const fil
          model->removeAllVertexInfluences( v );
       }
 
-      unsigned pcount = model->getVertexCount();
+      unsigned pcount = model->getPointCount();
       for ( unsigned p = 0; p < pcount; p++ )
       {
          model->removeAllPointInfluences( p );
@@ -1708,7 +1718,7 @@ Model::ModelErrorE MisfitFilter::readFile( Model * model, const char * const fil
                uv[0][0], uv[0][1], uv[1][0], uv[1][1] );
       }
 
-      log_debug( "read %d projections\n" );
+      log_debug( "read %d projections\n", count );
    }
 
    // Texture Projection Triangles (have to read this after projections)
@@ -1853,7 +1863,7 @@ Model::ModelErrorE MisfitFilter::readFile( Model * model, const char * const fil
 
          if ( size > m_src->getRemaining() )
          {
-            log_error( "Size of frame animation is too large for file data (%d > %d)\n",
+            log_error( "Size of frame animation is too large for file data (%d > %" PORTuSIZE ")\n",
                   size, m_src->getRemaining() );
             return Model::ERROR_BAD_DATA;
          }
@@ -1906,7 +1916,7 @@ Model::ModelErrorE MisfitFilter::readFile( Model * model, const char * const fil
             if ( (maxVertex) != modelVertices.size() )
             {
                missingElements = true;
-               log_error( "Vertex count for frame animation %d, frame %d has %d vertices, should be %d\n", anim, f, maxVertex, modelVertices.size() );
+               log_error( "Vertex count for frame animation %d, frame %d has %d vertices, should be %" PORTuSIZE "\n", anim, f, maxVertex, modelVertices.size() );
             }
          }
       }
@@ -2046,6 +2056,7 @@ Model::ModelErrorE MisfitFilter::readFile( Model * model, const char * const fil
       {
          if ( modelJoints[j]->m_parent >= (signed) jcount )
          {
+            // Misfit Model 3D 1.1.7 to 1.1.9 wrote joint parent as native endian while the rest of the file was little endian.
             log_warning( "Joint %d has bad parent joint, checking endianness\n", j );
             if ( htob_u32( modelJoints[j]->m_parent ) < jcount )
             {
@@ -2132,6 +2143,36 @@ Model::ModelErrorE MisfitFilter::writeFile( Model * model, const char * const fi
       }
    }
 
+   std::vector< std::string > texNames;
+   std::vector< int > materialTexMap;
+   unsigned materialCount = modelMaterials.size();
+   for ( unsigned m = 0; m < materialCount; m++ )
+   {
+      Model::Material * mat = modelMaterials[m];
+      if ( mat->m_type == Model::Material::MATTYPE_TEXTURE )
+      {
+         std::vector<std::string>::iterator it = std::find( texNames.begin(), texNames.end(), mat->m_filename );
+
+         if ( it == texNames.end() )
+         {
+            int texIndex = texNames.size();
+            log_debug( "material %s -> external texture %d (%s): New texture\n", mat->m_name.c_str(), texIndex, mat->m_filename.c_str() );
+            materialTexMap.push_back( texNames.size() );
+            texNames.push_back( mat->m_filename );
+         }
+         else
+         {
+            int texIndex = it - texNames.begin();
+            log_debug( "material %s -> external texture %d (%s): Reused texture\n", mat->m_name.c_str(), texIndex, texNames[texIndex].c_str() );
+            materialTexMap.push_back( it - texNames.begin() );
+         }
+      }
+      else
+      {
+         materialTexMap.push_back( 0 );
+      }
+   }
+
    bool haveProjectionTriangles = false;
    if ( model->getProjectionCount() > 0 )
    {
@@ -2152,7 +2193,7 @@ Model::ModelErrorE MisfitFilter::writeFile( Model * model, const char * const fi
    doWrite[ MDT_TriangleNormals ]     = (modelTriangles.size() > 0);
    doWrite[ MDT_Groups ]              = (modelGroups.size() > 0);
    doWrite[ MDT_Materials ]           = (modelMaterials.size() > 0);
-   doWrite[ MDT_ExtTextures ]         =  doWrite[ MDT_Materials ];
+   doWrite[ MDT_ExtTextures ]         = (texNames.size() > 0);
    doWrite[ MDT_TexCoords ]           = true; // Some users map texture coordinates before assigning a texture (think: paint texture)
    doWrite[ MDT_ProjectionTriangles ] = haveProjectionTriangles;
    doWrite[ MDT_CanvasBackgrounds ]   = (backgrounds > 0);
@@ -2245,8 +2286,8 @@ Model::ModelErrorE MisfitFilter::writeFile( Model * model, const char * const fi
 
          model->getMetaData( m, key, sizeof(key), value, sizeof(value) );
 
-         unsigned keyLen = strlen( key ) + 1;
-         unsigned valueLen = strlen( value ) + 1;
+         uint32_t keyLen = strlen( key ) + 1;
+         uint32_t valueLen = strlen( value ) + 1;
 
          m_dst->write(keyLen + valueLen);
 
@@ -2373,7 +2414,7 @@ Model::ModelErrorE MisfitFilter::writeFile( Model * model, const char * const fi
       for ( unsigned g = 0; g < count; g++ )
       {
          Model::Group * grp = modelGroups[g];
-         unsigned groupSize = baseSize + grp->m_name.length() + 1 
+         uint32_t groupSize = baseSize + grp->m_name.length() + 1
             + (grp->m_triangleIndices.size() * sizeof(uint32_t));
 
          uint16_t flags = 0x0000;
@@ -2402,8 +2443,6 @@ Model::ModelErrorE MisfitFilter::writeFile( Model * model, const char * const fi
       log_debug( "wrote %d groups\n", count );
    }
 
-   int texNum = 0;
-
    // Materials
    if ( doWrite[ MDT_Materials ] )
    {
@@ -2417,28 +2456,32 @@ Model::ModelErrorE MisfitFilter::writeFile( Model * model, const char * const fi
       unsigned baseSize = sizeof(uint16_t) + sizeof(uint32_t)
          + (sizeof(float32_t) * 17);
 
+      int internalTextures = 0;
+
       for ( unsigned m = 0; m < count; m++ )
       {
          Model::Material * mat = modelMaterials[m];
-         unsigned matSize = baseSize + mat->m_name.length() + 1;
+         uint32_t matSize = baseSize + mat->m_name.length() + 1;
 
          uint16_t flags = 0x0000;
-         uint32_t texIndex = texNum;  // TODO deal with embedded textures
+         uint32_t texIndex = materialTexMap[m];  // TODO deal with embedded textures
 
          switch ( mat->m_type )
          {
             case Model::Material::MATTYPE_COLOR:
                flags = 0x000d;
+               internalTextures++;
                break;
             case Model::Material::MATTYPE_GRADIENT:
                flags = 0x000e;
+               internalTextures++;
                break;
             case Model::Material::MATTYPE_BLANK:
                flags = 0x000f;
+               internalTextures++;
                break;
             case Model::Material::MATTYPE_TEXTURE:
                flags = 0x0000;
-               texNum++;
                break;
             default:
                break;
@@ -2484,7 +2527,7 @@ Model::ModelErrorE MisfitFilter::writeFile( Model * model, const char * const fi
          m_dst->write( lightProp );
 
       }
-      log_debug( "wrote %d materials with %d internal textures\n", count, texNum );
+      log_debug( "wrote %d materials with %d internal textures\n", count, internalTextures );
    }
 
    // External Textures
@@ -2493,37 +2536,33 @@ Model::ModelErrorE MisfitFilter::writeFile( Model * model, const char * const fi
       _setOffset( MDT_ExtTextures, m_dst->offset(), offsetList );
       _setUniformOffset( MDT_ExtTextures, false, offsetList );
 
-      unsigned count = modelMaterials.size();
+      unsigned count = texNames.size();
 
       writeHeaderA( 0x0000, count );
 
       unsigned baseSize = sizeof(uint16_t);
 
-      for ( unsigned m = 0; m < count; m++ )
+      for ( unsigned t = 0; t < count; t++ )
       {
-         Model::Material * mat = modelMaterials[m];
-         if ( mat->m_type == Model::Material::MATTYPE_TEXTURE )
-         {
-            std::string fileStr = getRelativePath( modelPath.c_str(), mat->m_filename.c_str() );
+         std::string fileStr = getRelativePath( modelPath.c_str(), texNames[t].c_str() );
 
-            char filename[PATH_MAX];
-            strncpy( filename, fileStr.c_str(), PATH_MAX );
-            utf8chrtrunc( filename, sizeof(filename)-1 );
+         char filename[PATH_MAX];
+         strncpy( filename, fileStr.c_str(), PATH_MAX );
+         utf8chrtrunc( filename, sizeof(filename)-1 );
 
-            replaceSlash( filename );
+         replaceSlash( filename );
 
-            unsigned texSize = baseSize + strlen(filename) + 1;
+         uint32_t texSize = baseSize + strlen(filename) + 1;
 
-            uint16_t flags = 0x0000;
+         uint16_t flags = 0x0000;
 
-            m_dst->write( texSize );
-            m_dst->write( flags );
-            m_dst->writeBytes( (const uint8_t *) filename, strlen(filename) + 1 );
+         m_dst->write( texSize );
+         m_dst->write( flags );
+         m_dst->writeBytes( (const uint8_t *) filename, strlen(filename) + 1 );
 
-            log_debug( "material file is %s\n", filename );
-         }
+         log_debug( "texture file is %s\n", filename );
       }
-      log_debug( "wrote %d external textures\n", texNum );
+      log_debug( "wrote %d external textures\n", count );
    }
 
    // Texture Coordinates
@@ -2571,6 +2610,8 @@ Model::ModelErrorE MisfitFilter::writeFile( Model * model, const char * const fi
 
       writeHeaderA( 0x0000, pcount );
 
+      unsigned totaltris = 0;
+
       for ( unsigned p = 0; p < pcount; p++ )
       {
          unsigned wcount = 0; // triangles to write
@@ -2585,6 +2626,8 @@ Model::ModelErrorE MisfitFilter::writeFile( Model * model, const char * const fi
             }
          }
 
+         totaltris += wcount;
+
          uint32_t triSize = sizeof(uint32_t) * 2 
                + sizeof(uint32_t) * wcount;
          uint32_t writeProj  = (uint32_t) p;
@@ -2603,7 +2646,7 @@ Model::ModelErrorE MisfitFilter::writeFile( Model * model, const char * const fi
             }
          }
       }
-      log_debug( "wrote %d external textures\n", texNum );
+      log_debug( "wrote %d triangles affected by a texture projection\n", totaltris );
    }
 
    // Canvas Backgrounds
@@ -2635,11 +2678,11 @@ Model::ModelErrorE MisfitFilter::writeFile( Model * model, const char * const fi
             cb.center[2] = cb.center[2];
 
             std::string fileStr = getRelativePath( modelPath.c_str(), file );
-            unsigned backSize = baseSize + fileStr.size() + 1;
+            uint32_t backSize = baseSize + fileStr.size() + 1;
 
             char * filedup = strdup( fileStr.c_str() );
             replaceSlash( filedup );
-            utf8chrtrunc( filedup, PATH_MAX-1 );
+            utf8chrtrunc( filedup, fileStr.size()-1 );
 
             m_dst->write( backSize );
             m_dst->write( cb.flags );
@@ -2957,7 +3000,7 @@ Model::ModelErrorE MisfitFilter::writeFile( Model * model, const char * const fi
       for ( unsigned s = 0; s < count; s++ )
       {
          Model::SkelAnim * sa = modelSkels[s];
-         unsigned animSize = baseSize + sa->m_name.length() + 1;
+         uint32_t animSize = baseSize + sa->m_name.length() + 1;
 
          uint32_t frameCount = sa->m_frameCount;
          uint32_t keyframeCount = 0;
@@ -3057,7 +3100,7 @@ Model::ModelErrorE MisfitFilter::writeFile( Model * model, const char * const fi
       for ( unsigned a = 0; a < count; a++ )
       {
          Model::FrameAnim * fa = modelFrames[a];
-         unsigned animSize = baseSize + fa->m_name.length() + 1;
+         uint32_t animSize = baseSize + fa->m_name.length() + 1;
 
          uint32_t frameCount = fa->m_frameData.size();
 
