@@ -1064,6 +1064,7 @@ Model::ModelErrorE MisfitFilterRef::readFile( Model * model, const char * const
    {
       bool     variable = _offsetIsVariable( MDT_ExtTextures, offsetList );
       uint32_t offset   = _offsetGet( MDT_ExtTextures, offsetList );
+      uint32_t texcoordsOffset = _offsetGet( MDT_TexCoords, offsetList );
 
       m_bufPos     = &fileBuf[offset];
       m_readLength = fileLength - offset;
@@ -1081,6 +1082,14 @@ Model::ModelErrorE MisfitFilterRef::readFile( Model * model, const char * const
 
       for ( unsigned t = 0; t < count; t++ )
       {
+         // Before Maverick Model 3D 1.3.13, MM3D wrote external texture count as material count.
+         // It may be higher than the number of textures written to the file.
+         if ( texcoordsOffset >= offset && (uint32_t)( m_bufPos - fileBuf ) >= texcoordsOffset )
+         {
+            log_debug( "invalid external texture count (should be %d instead of %d)\n", t, count );
+            break;
+         }
+
          log_debug( "reading external texture %d/%d\n", t, count );
          if ( variable )
          {
@@ -1184,7 +1193,7 @@ Model::ModelErrorE MisfitFilterRef::readFile( Model * model, const char * const
                memset( mat->m_color, 255, sizeof( mat->m_color ) );
                break;
             default:
-               log_debug( "  got unknown material type\n", texIndex );
+               log_debug( "  got unknown material type %d\n", flags & 0x0f );
                mat->m_type = Model::Material::MATTYPE_BLANK;
                mat->m_filename = "";
                memset( mat->m_color, 255, sizeof( mat->m_color ) );
@@ -1511,7 +1520,7 @@ Model::ModelErrorE MisfitFilterRef::readFile( Model * model, const char * const
          }
       }
 
-      log_debug( "read %d points\n" );
+      log_debug( "read %d points\n", count );
    }
 
    // Smooth Angles
@@ -1585,7 +1594,7 @@ Model::ModelErrorE MisfitFilterRef::readFile( Model * model, const char * const
          model->removeAllVertexInfluences( v );
       }
 
-      unsigned pcount = model->getVertexCount();
+      unsigned pcount = model->getPointCount();
       for ( unsigned p = 0; p < pcount; p++ )
       {
          model->removeAllPointInfluences( p );
@@ -1726,7 +1735,7 @@ Model::ModelErrorE MisfitFilterRef::readFile( Model * model, const char * const
                uv[0][0], uv[0][1], uv[1][0], uv[1][1] );
       }
 
-      log_debug( "read %d projections\n" );
+      log_debug( "read %d projections\n", count );
    }
 
    // Texture Projection Triangles (have to read this after projections)
@@ -2077,6 +2086,7 @@ Model::ModelErrorE MisfitFilterRef::readFile( Model * model, const char * const
       {
          if ( modelJoints[j]->m_parent >= (signed) jcount )
          {
+            // Misfit Model 3D 1.1.7 to 1.1.9 wrote joint parent as native endian while the rest of the file was little endian.
             log_warning( "Joint %d has bad parent joint, checking endianness\n", j );
             if ( htob_u32( modelJoints[j]->m_parent ) < jcount )
             {
