@@ -1189,7 +1189,13 @@ class Model
       // Interpolate what a keyframe for this joint would be at the specified time.
       bool interpSkelAnimKeyframeTime( unsigned anim, double frameTime,
             bool loop, unsigned joint,
-            Matrix & relativeFinal ) const;
+            Matrix & relativeFinal,
+            double minFrameTime = -1.0, double maxFrameTime = -1.0 ) const;
+
+      // Create keyframes needed to match pose at 'sourceAnim' 'sourceFrame'.
+      // This allows split or tracated animation to keep the same animation pose.
+      void copyInterpSkelAnimKeyframes( unsigned destAnim, unsigned destFrame, bool destLoop, unsigned destLastFrame,
+            unsigned sourceAnim, unsigned sourceFrame, bool sourceLoop );
 
       // Animation set operations
       int  copyAnimation( AnimationModeE mode, unsigned anim, const char * newName );
@@ -1310,7 +1316,7 @@ class Model
       // The model argument should be const, but it calls setupJoints.
       // TODO: Calling setupJoints in here should not be necessary.
       bool mergeModels( Model * model, bool textures, AnimationMergeE mergeMode, bool emptyGroups,
-            double * trans = NULL, double * rot = NULL );
+            int point = -1, double * trans = NULL, double * rot = NULL );
 
       // These are helper functions for the boolean operations
       void removeInternalTriangles( 
@@ -1578,7 +1584,7 @@ class Model
 
       // These functions are for undo and features such as this.
       // Don't use them unless you are me.
-      void insertVertex( unsigned index, Vertex * vertex );
+      void insertVertex( unsigned index, Vertex * vertex, vector<FrameAnimVertex *> * vertexAnimFrames = NULL );
       void removeVertex( unsigned index );
 
       void insertTriangle( unsigned index, Triangle * triangle );
@@ -1593,7 +1599,7 @@ class Model
       void insertInfluence( const Position & pos, unsigned index, const InfluenceT & influence );
       void removeInfluence( const Position & pos, unsigned index );
 
-      void insertPoint( unsigned index, Point * point );
+      void insertPoint( unsigned index, Point * point, vector<FrameAnimPoint *> * pointAnimFrames = NULL );
       void removePoint( unsigned index );
 
       void insertProjection( unsigned index, TextureProjection * proj );
