@@ -30,6 +30,7 @@
 #include "log.h"
 #include "glmath.h"
 #include <math.h>
+#include <limits.h>
 
 #ifdef MM3D_EDIT
 
@@ -50,7 +51,7 @@ int Model::addAnimation( AnimationModeE m, const char * name )
                anim->m_name = name;
                anim->m_fps  = 30.0;
                anim->m_spf  = (1.0 / anim->m_fps);
-               anim->m_loop = true;
+               anim->m_loop = false;
                anim->m_frameCount = 1;
                anim->m_validNormals = false;
 
@@ -74,7 +75,7 @@ int Model::addAnimation( AnimationModeE m, const char * name )
                FrameAnim * anim = FrameAnim::get();
                anim->m_name = name;
                anim->m_fps = 10.0;
-               anim->m_loop = true;
+               anim->m_loop = false;
                anim->m_validNormals = false;
 
                MU_AddAnimation * undo = new MU_AddAnimation();
@@ -360,6 +361,11 @@ void Model::setFrameAnimPointCount( unsigned pointCount )
    for ( anim = 0; anim < acount; anim++ )
    {
       unsigned fcount = m_frameAnims[ anim ]->m_frameData.size();
+      if ( fcount == 0 )
+      {
+         continue;
+      }
+
       oldCount = m_frameAnims[anim]->m_frameData[0]->m_framePoints->size();
       for ( frame = 0; frame < fcount; frame++ )
       {
@@ -516,6 +522,11 @@ void Model::setFrameAnimVertexCount( unsigned vertexCount )
    for ( anim = 0; anim < acount; anim++ )
    {
       unsigned fcount = m_frameAnims[ anim ]->m_frameData.size();
+      if ( fcount == 0 )
+      {
+         continue;
+      }
+
       oldCount = m_frameAnims[anim]->m_frameData[0]->m_frameVertices->size();
       for ( frame = 0; frame < fcount; frame++ )
       {
@@ -683,13 +694,18 @@ int Model::splitAnimation( AnimationModeE mode, unsigned anim, const char * newN
    switch ( mode )
    {
       case ANIMMODE_SKELETAL:
-         if ( anim < m_skelAnims.size() )
+         if ( anim < m_skelAnims.size()
+               && frame < m_skelAnims[anim]->m_frameCount )
          {
             num = addAnimation( mode, newName );
             if ( num >= 0 )
             {
+               bool loop = getAnimLooping( mode, anim );
+               bool newloop = loop;
+
                setAnimFrameCount( mode, num, getAnimFrameCount( mode, anim ) - frame );
                setAnimFPS( mode, num, getAnimFPS( mode, anim ) );
+               setAnimLooping( mode, num, newloop );
 
                SkelAnim * sa = m_skelAnims[anim];
 
@@ -707,19 +723,43 @@ int Model::splitAnimation( AnimationModeE mode, unsigned anim, const char * newN
                   }
                }
 
+               // create keyframes at the split point if needed
+               copyInterpSkelAnimKeyframes( anim, frame - 1, loop, frame - 1,
+                                            anim, frame - 1, loop );
+               copyInterpSkelAnimKeyframes( num,  0,         newloop, UINT_MAX,
+                                            anim, frame,     loop );
+
+               // create keyframes at the other ends if needed
+               if ( loop )
+               {
+                  copyInterpSkelAnimKeyframes( anim, 0, loop, frame - 1,
+                                               anim, 0, loop );
+               }
+               if ( newloop )
+               {
+                  copyInterpSkelAnimKeyframes( num,  getAnimFrameCount( mode, num ) - 1, newloop, UINT_MAX,
+                                               anim, getAnimFrameCount( mode, anim ) - 1, loop );
+               }
+
                setAnimFrameCount( mode, anim, frame );
-               moveAnimation( mode, num, anim + 1 );
+
+               if ( moveAnimation( mode, num, anim + 1 ) )
+               {
+                  num = anim + 1;
+               }
             }
          }
          break;
       case ANIMMODE_FRAME:
-         if ( anim < m_frameAnims.size() )
+         if ( anim < m_frameAnims.size()
+               && frame < m_frameAnims[anim]->m_frameData.size() )
          {
             num = addAnimation( mode, newName );
             if ( num >= 0 )
             {
                setAnimFrameCount( mode, num, getAnimFrameCount( mode, anim ) - frame );
                setAnimFPS( mode, num, getAnimFPS( mode, anim ) );
+               setAnimLooping( mode, num, getAnimLooping( mode, anim ) );
 
                FrameAnim * fa = m_frameAnims[anim];
 
@@ -740,7 +780,11 @@ int Model::splitAnimation( AnimationModeE mode, unsigned anim, const char * newN
                }
 
                setAnimFrameCount( mode, anim, frame );
-               moveAnimation( mode, num, anim + 1 );
+
+               if ( moveAnimation( mode, num, anim + 1 ) )
+               {
+                  num = anim + 1;
+               }
             }
          }
          break;
@@ -753,6 +797,57 @@ int Model::splitAnimation( AnimationModeE mode, unsigned anim, const char * newN
    return num;
 }
 
+void Model::copyInterpSkelAnimKeyframes( unsigned destAnim, unsigned destFrame, bool destLoop, unsigned destLastFrame, unsigned sourceAnim, unsigned sourceFrame, bool sourceLoop )
+{
+   if ( destAnim < m_skelAnims.size()
+         && destFrame < m_skelAnims[destAnim]->m_frameCount
+         && sourceAnim < m_skelAnims.size()
+         && sourceFrame < m_skelAnims[sourceAnim]->m_frameCount )
+   {
+      SkelAnim * souceSA = m_skelAnims[sourceAnim];
+      double sourceTotalTime = souceSA->m_spf * souceSA->m_frameCount;
+      double sourceFrameTime = (double) sourceFrame / (double) souceSA->m_frameCount
+                      * sourceTotalTime;
+
+      SkelAnim * destSA = m_skelAnims[destAnim];
+      double destTotalTime = destSA->m_spf * destSA->m_frameCount;
+      double destFrameTime = (double) destFrame / (double) destSA->m_frameCount
+                      * destTotalTime;
+      double destLastFrameTime = ( destLastFrame == UINT_MAX ) ? -1.0 :
+                               ( (double) destLastFrame / (double) destSA->m_frameCount
+                      * destTotalTime );
+
+      for ( size_t j = 0; j < m_joints.size(); j++ )
+      {
+         Matrix sourceMatrix;
+         double sourceTrans[3];
+         double sourceRot[3];
+
+         interpSkelAnimKeyframeTime( sourceAnim, sourceFrameTime, sourceLoop, j, sourceMatrix );
+         sourceMatrix.getTranslation( sourceTrans[0], sourceTrans[1], sourceTrans[2] );
+         sourceMatrix.getRotation( sourceRot[0], sourceRot[1], sourceRot[2] );
+
+         Matrix destMatrix;
+         double destTrans[3];
+         double destRot[3];
+
+         interpSkelAnimKeyframeTime( destAnim, destFrameTime, destLoop, j, destMatrix, -1.0, destLastFrameTime );
+         destMatrix.getTranslation( destTrans[0], destTrans[1], destTrans[2] );
+         destMatrix.getRotation( destRot[0], destRot[1], destRot[2] );
+
+         if ( !floatCompareVector( destTrans, sourceTrans, 3 ) )
+         {
+            setSkelAnimKeyframe( destAnim, destFrame, j, false, sourceTrans[0], sourceTrans[1], sourceTrans[2] );
+         }
+
+         if ( !floatCompareVector( destRot, sourceRot, 3 ) )
+         {
+            setSkelAnimKeyframe( destAnim, destFrame, j, true, sourceRot[0], sourceRot[1], sourceRot[2] );
+         }
+      }
+   }
+}
+
 bool Model::joinAnimations( AnimationModeE mode, unsigned anim1, unsigned anim2 )
 {
    log_debug( "join %d anim %d + %d\n", mode, anim1, anim2 );
@@ -1148,7 +1243,7 @@ int Model::setSkelAnimKeyframe( unsigned anim, unsigned frame, unsigned joint, b
       log_error( "anim keyframe out of range: anim %d, frame %d, joint %d\n", anim, frame, joint );
       if ( anim < m_skelAnims.size() )
       {
-         log_error( "max frame is %d, max joint is %d\n", m_skelAnims[anim]->m_frameCount, m_joints.size() );
+         log_error( "max frame is %d, max joint is %" PORTuSIZE "\n", m_skelAnims[anim]->m_frameCount, m_joints.size() );
       }
       return -1;
    }
@@ -1164,7 +1259,7 @@ bool Model::deleteSkelAnimKeyframe( unsigned anim, unsigned frame, unsigned join
       {
          if ( (*it)->m_frame == frame && (*it)->m_isRotation == isRotation )
          {
-            log_debug( "deleting keyframe for anim %d frame %d joint %d\n", anim, frame, joint, isRotation ? "rotation" : "translation" );
+            log_debug( "deleting %s keyframe for anim %d frame %d joint %d\n", isRotation ? "rotation" : "translation", anim, frame, joint );
             MU_DeleteKeyframe * undo = new MU_DeleteKeyframe;
             undo->setAnimationData( anim );
             undo->deleteKeyframe( *it );
@@ -1254,7 +1349,7 @@ void Model::insertFrameAnim( unsigned index, FrameAnim * anim )
    }
    else
    {
-      log_error( "index %d/%d out of range in insertFrameAnim\n", index, m_frameAnims.size() );
+      log_error( "index %d/%" PORTuSIZE " out of range in insertFrameAnim\n", index, m_frameAnims.size() );
    }
 }
 
@@ -1308,7 +1403,7 @@ void Model::insertSkelAnim( unsigned index, SkelAnim * anim )
    }
    else
    {
-      log_error( "index %d/%d out of range in insertSkelAnim\n", index, m_skelAnims.size() );
+      log_error( "index %d/%" PORTuSIZE " out of range in insertSkelAnim\n", index, m_skelAnims.size() );
    }
 }
 
@@ -1364,7 +1459,7 @@ void Model::insertFrameAnimFrame( unsigned anim, unsigned frame,
       }
       else
       {
-         log_error( "frame %d/%d out of range in insertFrameAnimFrame for frame %d\n", frame, fa->m_frameData.size(), anim );
+         log_error( "frame %d/%" PORTuSIZE " out of range in insertFrameAnimFrame for frame %d\n", frame, fa->m_frameData.size(), anim );
       }
    }
 }
@@ -2409,8 +2504,8 @@ bool Model::getSkelAnimKeyframe( unsigned anim, unsigned frame,
       bool found = false;
       if ( m_skelAnims[anim]->m_jointKeyframes[joint].find_sorted( kf, index ) )
       {
-//         log_debug( "found keyframe anim %d, frame %d, joint %d, %s\n",
-//               anim, frame, joint, isRotation ? "rotation" : "translation" );
+//         log_debug( "found %s keyframe for anim %d, frame %d, joint %d\n",
+//               isRotation ? "rotation" : "translation", anim, frame, joint );
          x = m_skelAnims[anim]->m_jointKeyframes[joint][index]->m_parameter[0];
          y = m_skelAnims[anim]->m_jointKeyframes[joint][index]->m_parameter[1];
          z = m_skelAnims[anim]->m_jointKeyframes[joint][index]->m_parameter[2];
@@ -2418,8 +2513,8 @@ bool Model::getSkelAnimKeyframe( unsigned anim, unsigned frame,
       }
       else
       {
-         //log_debug( "could not find keyframe anim %d, frame %d, joint %d, %s\n",
-         //      anim, frame, joint, isRotation ? "rotation" : "translation" );
+         //log_debug( "could not find %s keyframe for anim %d, frame %d, joint %d\n",
+         //      isRotation ? "rotation" : "translation", anim, frame, joint );
       }
       kf->release();
 
@@ -2464,7 +2559,7 @@ bool Model::interpSkelAnimKeyframe( unsigned anim, unsigned frame,
 }
 
 bool Model::interpSkelAnimKeyframeTime( unsigned anim, double frameTime,
-      bool loop, unsigned j, Matrix & transform ) const
+      bool loop, unsigned j, Matrix & transform, double minFrameTime, double maxFrameTime ) const
 {
    if ( anim < m_skelAnims.size() && j < m_joints.size() )
    {
@@ -2493,6 +2588,15 @@ bool Model::interpSkelAnimKeyframeTime( unsigned anim, double frameTime,
          int tran = -1;
          for ( unsigned k = 0; k < sa->m_jointKeyframes[j].size(); k++ )
          {
+            if ( minFrameTime > 0.0 && sa->m_jointKeyframes[j][k]->m_time < minFrameTime )
+            {
+               continue;
+            }
+            if ( maxFrameTime > 0.0 && sa->m_jointKeyframes[j][k]->m_time > maxFrameTime )
+            {
+               continue;
+            }
+
             if ( sa->m_jointKeyframes[j][k]->m_isRotation )
             {
                if ( firstRot == -1 )
