@@ -592,9 +592,9 @@ void Model::draw( unsigned drawOptions, ContextT context, float * viewPoint )
                         }
 
                         glTexParameteri( GL_TEXTURE_2D, GL_TEXTURE_WRAP_S, 
-                              (m_materials[ grp->m_materialIndex ]->m_sClamp ? GL_CLAMP : GL_REPEAT) );
+                              (m_materials[ grp->m_materialIndex ]->m_sClamp ? GL_CLAMP_TO_EDGE : GL_REPEAT) );
                         glTexParameteri( GL_TEXTURE_2D, GL_TEXTURE_WRAP_T, 
-                              (m_materials[ grp->m_materialIndex ]->m_tClamp ? GL_CLAMP : GL_REPEAT) );
+                              (m_materials[ grp->m_materialIndex ]->m_tClamp ? GL_CLAMP_TO_EDGE : GL_REPEAT) );
 
                         glEnable( GL_TEXTURE_2D );
                      }
@@ -796,9 +796,9 @@ void Model::draw( unsigned drawOptions, ContextT context, float * viewPoint )
                            }
 
                            glTexParameteri( GL_TEXTURE_2D, GL_TEXTURE_WRAP_S, 
-                                 (m_materials[ grp->m_materialIndex ]->m_sClamp ? GL_CLAMP : GL_REPEAT) );
+                                 (m_materials[ grp->m_materialIndex ]->m_sClamp ? GL_CLAMP_TO_EDGE : GL_REPEAT) );
                            glTexParameteri( GL_TEXTURE_2D, GL_TEXTURE_WRAP_T, 
-                                 (m_materials[ grp->m_materialIndex ]->m_tClamp ? GL_CLAMP : GL_REPEAT) );
+                                 (m_materials[ grp->m_materialIndex ]->m_tClamp ? GL_CLAMP_TO_EDGE : GL_REPEAT) );
 
                            glEnable( GL_TEXTURE_2D );
                         }
@@ -995,9 +995,9 @@ void Model::draw( unsigned drawOptions, ContextT context, float * viewPoint )
                      }
 
                      glTexParameteri( GL_TEXTURE_2D, GL_TEXTURE_WRAP_S, 
-                           (m_materials[ grp->m_materialIndex ]->m_sClamp ? GL_CLAMP : GL_REPEAT) );
+                           (m_materials[ grp->m_materialIndex ]->m_sClamp ? GL_CLAMP_TO_EDGE : GL_REPEAT) );
                      glTexParameteri( GL_TEXTURE_2D, GL_TEXTURE_WRAP_T, 
-                           (m_materials[ grp->m_materialIndex ]->m_tClamp ? GL_CLAMP : GL_REPEAT) );
+                           (m_materials[ grp->m_materialIndex ]->m_tClamp ? GL_CLAMP_TO_EDGE : GL_REPEAT) );
 
                      glEnable( GL_TEXTURE_2D );
                   }
@@ -1019,6 +1019,8 @@ void Model::draw( unsigned drawOptions, ContextT context, float * viewPoint )
                _defaultMaterial();
             }
 
+            glEnable( GL_LIGHT0 );
+            glDisable( GL_LIGHT1 );
             colorSelected = false;
 
             glBegin( GL_TRIANGLES );
@@ -1039,12 +1041,14 @@ void Model::draw( unsigned drawOptions, ContextT context, float * viewPoint )
                         {
                            glColor3f( 1.0, 0.0, 0.0 );
                         }
+
                         glEnd();
                         glDisable( GL_LIGHT0 );
                         glEnable( GL_LIGHT1 );
                         glBegin( GL_TRIANGLES );
+
+                        colorSelected = true;
                      }
-                     colorSelected = true;
                   }
                   else
                   {
@@ -1054,12 +1058,14 @@ void Model::draw( unsigned drawOptions, ContextT context, float * viewPoint )
                         {
                            glColor3f( 0.9, 0.9, 0.9 );
                         }
+
+                        glEnd();
+                        glDisable( GL_LIGHT1 );
+                        glEnable( GL_LIGHT0 );
+                        glBegin( GL_TRIANGLES );
+
+                        colorSelected = false;
                      }
-                     glEnd();
-                     glDisable( GL_LIGHT1 );
-                     glEnable( GL_LIGHT0 );
-                     glBegin( GL_TRIANGLES );
-                     colorSelected = false;
                   }
 
                   for ( int v = 0; v < 3; v++ )
@@ -1082,6 +1088,11 @@ void Model::draw( unsigned drawOptions, ContextT context, float * viewPoint )
             glEnd();
          }
 
+         glColor3f( 0.9, 0.9, 0.9 );
+         glEnable( GL_LIGHT0 );
+         glDisable( GL_LIGHT1 );
+         colorSelected = false;
+
          // Draw ungrouped triangles
          {
             _defaultMaterial();
@@ -1101,24 +1112,28 @@ void Model::draw( unsigned drawOptions, ContextT context, float * viewPoint )
                         if ( colorSelected == false )
                         {
                            glColor3f( 1.0, 0.0, 0.0 );
+
+                           glEnd();
+                           glDisable( GL_LIGHT0 );
+                           glEnable( GL_LIGHT1 );
+                           glBegin( GL_TRIANGLES );
+
+                           colorSelected = true;
                         }
-                        glEnd();
-                        glDisable( GL_LIGHT0 );
-                        glEnable( GL_LIGHT1 );
-                        glBegin( GL_TRIANGLES );
-                        colorSelected = true;
                      }
                      else
                      {
                         if ( colorSelected == true )
                         {
                            glColor3f( 0.9, 0.9, 0.9 );
+
+                           glEnd();
+                           glDisable( GL_LIGHT1 );
+                           glEnable( GL_LIGHT0 );
+                           glBegin( GL_TRIANGLES );
+
+                           colorSelected = false;
                         }
-                        glEnd();
-                        glDisable( GL_LIGHT1 );
-                        glEnable( GL_LIGHT0 );
-                        glBegin( GL_TRIANGLES );
-                        colorSelected = false;
                      }
 
                      for ( int v = 0; v < 3; v++ )
