@@ -25,11 +25,8 @@
 #include "texture.h"
 #include "log.h"
 
-#include <ext/hash_set>
 #include <map>
 
-using __gnu_cxx::hash_set;
-
 static bool _model_recycle = true;
 
 int Model::Vertex::s_allocated = 0;
@@ -57,7 +54,7 @@ list<Model::FrameAnim *> Model::FrameAnim::s_recycle;
 list<Model::FrameAnimVertex *> Model::FrameAnimVertex::s_recycle;
 list<Model::FrameAnimPoint *> Model::FrameAnimPoint::s_recycle;
 
-const double EQ_TOLERANCE = 0.00001;
+extern const double EQ_TOLERANCE;
 
 template<typename T>
 bool floatCompareVector( T * lhs, T * rhs, size_t len, double tolerance = EQ_TOLERANCE )
@@ -162,7 +159,7 @@ int Model::Vertex::flush()
 
 void Model::Vertex::stats()
 {
-   log_debug( "Vertex: %d/%d\n", s_recycle.size(), s_allocated );
+   log_debug( "Vertex: %" PORTuSIZE "/%d\n", s_recycle.size(), s_allocated );
 }
 
 Model::Vertex * Model::Vertex::get()
@@ -274,7 +271,7 @@ int Model::Triangle::flush()
 
 void Model::Triangle::stats()
 {
-   log_debug( "Triangle: %d/%d\n", s_recycle.size(), s_allocated );
+   log_debug( "Triangle: %" PORTuSIZE "/%d\n", s_recycle.size(), s_allocated );
 }
 
 Model::Triangle * Model::Triangle::get()
@@ -384,7 +381,7 @@ int Model::Group::flush()
 
 void Model::Group::stats()
 {
-   log_debug( "Group: %d/%d\n", s_recycle.size(), s_allocated );
+   log_debug( "Group: %" PORTuSIZE "/%d\n", s_recycle.size(), s_allocated );
 }
 
 Model::Group * Model::Group::get()
@@ -491,7 +488,7 @@ int Model::Material::flush()
 
 void Model::Material::stats()
 {
-   log_debug( "Material: %d/%d\n", s_recycle.size(), s_allocated );
+   log_debug( "Material: %" PORTuSIZE "/%d\n", s_recycle.size(), s_allocated );
 }
 
 Model::Material * Model::Material::get()
@@ -619,7 +616,7 @@ int Model::Keyframe::flush()
 
 void Model::Keyframe::stats()
 {
-   log_debug( "Keyframe: %d/%d\n", s_recycle.size(), s_allocated );
+   log_debug( "Keyframe: %" PORTuSIZE "/%d\n", s_recycle.size(), s_allocated );
 }
 
 Model::Keyframe * Model::Keyframe::get()
@@ -735,7 +732,7 @@ int Model::Joint::flush()
 
 void Model::Joint::stats()
 {
-   log_debug( "Joint: %d/%d\n", s_recycle.size(), s_allocated );
+   log_debug( "Joint: %" PORTuSIZE "/%d\n", s_recycle.size(), s_allocated );
 }
 
 bool Model::Joint::propEqual(const Joint & rhs, int propBits, double tolerance ) const
@@ -850,7 +847,7 @@ int Model::Point::flush()
 
 void Model::Point::stats()
 {
-   log_debug( "Point: %d/%d\n", s_recycle.size(), s_allocated );
+   log_debug( "Point: %" PORTuSIZE "/%d\n", s_recycle.size(), s_allocated );
 }
 
 bool Model::Point::propEqual(const Point & rhs, int propBits, double tolerance ) const
@@ -1094,7 +1091,7 @@ int Model::SkelAnim::flush()
 
 void Model::SkelAnim::stats()
 {
-   log_debug( "SkelAnim: %d/%d\n", s_recycle.size(), s_allocated );
+   log_debug( "SkelAnim: %" PORTuSIZE "/%d\n", s_recycle.size(), s_allocated );
 }
 
 bool Model::SkelAnim::propEqual(const SkelAnim & rhs, int propBits, double tolerance ) const
@@ -1143,7 +1140,7 @@ bool Model::SkelAnim::propEqual(const SkelAnim & rhs, int propBits, double toler
    {
       if ( m_jointKeyframes.size() != rhs.m_jointKeyframes.size() )
       {
-         log_warning( "match failed at anim keyframe size, lhs = %d, rhs = %d\n",
+         log_warning( "match failed at anim keyframe size, lhs = %" PORTuSIZE ", rhs = %" PORTuSIZE "\n",
                m_jointKeyframes.size(), rhs.m_jointKeyframes.size() );
          return false;
       }
@@ -1265,7 +1262,7 @@ int Model::FrameAnim::flush()
 
 void Model::FrameAnim::stats()
 {
-   log_debug( "FrameAnim: %d/%d\n", s_recycle.size(), s_allocated );
+   log_debug( "FrameAnim: %" PORTuSIZE "/%d\n", s_recycle.size(), s_allocated );
 }
 
 bool Model::FrameAnim::propEqual(const FrameAnim & rhs, int propBits, double tolerance ) const
@@ -1304,7 +1301,7 @@ bool Model::FrameAnim::propEqual(const FrameAnim & rhs, int propBits, double tol
    {
       if ( m_frameData.size() != rhs.m_frameData.size() )
       {
-         log_warning( "match failed at anim frame size lhs %d, rhs %d\n",
+         log_warning( "match failed at anim frame size lhs %" PORTuSIZE ", rhs %" PORTuSIZE "\n",
                m_frameData.size(), rhs.m_frameData.size() );
          return false;
       }
@@ -1316,7 +1313,7 @@ bool Model::FrameAnim::propEqual(const FrameAnim & rhs, int propBits, double tol
       {
          if ( !(*lhs_it)->propEqual( **rhs_it, propBits, tolerance ) )
          {
-            log_warning( "match failed at frame %d\n", lhs_it - m_frameData.begin() );
+            log_warning( "match failed at frame %" PORTdDIFF "\n", lhs_it - m_frameData.begin() );
             return false;
          }
       }
@@ -1388,7 +1385,7 @@ int Model::FrameAnimVertex::flush()
 
 void Model::FrameAnimVertex::stats()
 {
-   log_debug( "FrameAnimVertex: %d/%d\n", s_recycle.size(), s_allocated );
+   log_debug( "FrameAnimVertex: %" PORTuSIZE "/%d\n", s_recycle.size(), s_allocated );
 }
 
 bool Model::FrameAnimVertex::propEqual(const FrameAnimVertex & rhs, int propBits, double tolerance ) const
@@ -1470,7 +1467,7 @@ int Model::FrameAnimPoint::flush()
 
 void Model::FrameAnimPoint::stats()
 {
-   log_debug( "FrameAnimPoint: %d/%d\n", s_recycle.size(), s_allocated );
+   log_debug( "FrameAnimPoint: %" PORTuSIZE "/%d\n", s_recycle.size(), s_allocated );
 }
 
 bool Model::FrameAnimPoint::propEqual(const FrameAnimPoint & rhs, int propBits, double tolerance ) const
@@ -1507,14 +1504,14 @@ bool Model::FrameAnimData::propEqual(const FrameAnimData & rhs, int propBits, do
    {
       if ( m_frameVertices->size() != rhs.m_frameVertices->size() )
       {
-         log_warning( "anim frame vertex size mismatch lhs %d, rhs %d\n",
+         log_warning( "anim frame vertex size mismatch lhs %" PORTuSIZE ", rhs %" PORTuSIZE "\n",
                m_frameVertices->size(), rhs.m_frameVertices->size() );
          return false;
       }
 
       if ( m_framePoints->size() != rhs.m_framePoints->size() )
       {
-         log_warning( "anim frame point size mismatch lhs %d, rhs %d\n",
+         log_warning( "anim frame point size mismatch lhs %" PORTuSIZE ", rhs %" PORTuSIZE "\n",
                m_framePoints->size(), rhs.m_framePoints->size() );
          return false;
       }
@@ -1526,7 +1523,7 @@ bool Model::FrameAnimData::propEqual(const FrameAnimData & rhs, int propBits, do
       {
          if ( !(*lv)->propEqual( **rv, propBits, tolerance ) )
          {
-            log_warning( "anim frame vertex mismatch at %d\n",
+            log_warning( "anim frame vertex mismatch at %" PORTdDIFF "\n",
                   lv - m_frameVertices->begin() );
             return false;
          }
@@ -1539,7 +1536,7 @@ bool Model::FrameAnimData::propEqual(const FrameAnimData & rhs, int propBits, do
       {
          if ( !(*lp)->propEqual( **rp, propBits, tolerance ) )
          {
-            log_warning( "anim frame point mismatch at %d\n",
+            log_warning( "anim frame point mismatch at %" PORTdDIFF "\n",
                   lp - m_framePoints->begin() );
             return false;
          }
