@@ -352,7 +352,7 @@ bool Model::equivalent( const Model * model, double tolerance ) const
 
       if ( gtris.size() != rgtris.size() )
       {
-         log_warning( "lhs group %d triangles = %d, rhs = %d (not fatal)\n",
+         log_warning( "lhs group %d triangles = %" PORTuSIZE ", rhs = %" PORTuSIZE " (not fatal)\n",
                g, gtris.size(), rgtris.size() );
       }
 
@@ -559,7 +559,7 @@ bool Model::equivalent( const Model * model, double tolerance ) const
       if ( fabs( getAnimFPS( mode, a ) - model->getAnimFPS( mode, a ) )
             > tolerance )
       {
-         log_warning( "animation fps mismatch on %d, lhs = %d, rhs = %d\n",
+         log_warning( "animation fps mismatch on %d, lhs = %f, rhs = %f\n",
                a, model->getAnimFPS( mode, a ), model->getAnimFPS( mode, a ) );
          return false;
       }
@@ -672,7 +672,7 @@ bool Model::equivalent( const Model * model, double tolerance ) const
       if ( fabs( getAnimFPS( mode, a ) - model->getAnimFPS( mode, a ) )
             > tolerance )
       {
-         log_warning( "animation fps mismatch on %d, lhs = %d, rhs = %d\n",
+         log_warning( "animation fps mismatch on %d, lhs = %f, rhs = %f\n",
                a, model->getAnimFPS( mode, a ), model->getAnimFPS( mode, a ) );
          return false;
       }
@@ -763,7 +763,7 @@ bool Model::propEqual( const Model * model, int partBits, int propBits,
    {
       if (numVertices != model->m_vertices.size())
       {
-         log_warning( "match failed at vertex count %d != %d\n",
+         log_warning( "match failed at vertex count %d != %" PORTuSIZE "\n",
                numVertices, model->m_vertices.size() );
          return false;
       }
@@ -786,7 +786,7 @@ bool Model::propEqual( const Model * model, int partBits, int propBits,
    {
       if (numTriangles != model->m_triangles.size())
       {
-         log_warning( "match failed at triangle count %d != %d\n",
+         log_warning( "match failed at triangle count %d != %" PORTuSIZE "\n",
                numTriangles, model->m_triangles.size() );
          return false;
       }
@@ -809,7 +809,7 @@ bool Model::propEqual( const Model * model, int partBits, int propBits,
    {
       if ( numGroups != (unsigned) model->getGroupCount() )
       {
-         log_warning( "match failed at group count %d != %d\n",
+         log_warning( "match failed at group count %d != %" PORTuSIZE "\n",
                numGroups, model->m_groups.size() );
          return false;
       }
@@ -832,7 +832,7 @@ bool Model::propEqual( const Model * model, int partBits, int propBits,
    {
       if ( numJoints != model->m_joints.size() )
       {
-         log_warning( "match failed at joint count %d != %d\n",
+         log_warning( "match failed at joint count %d != %" PORTuSIZE "\n",
                numJoints, model->m_joints.size() );
          return false;
       }
@@ -855,7 +855,7 @@ bool Model::propEqual( const Model * model, int partBits, int propBits,
    {
       if ( numPoints != model->m_points.size() )
       {
-         log_warning( "match failed at point count %d != %d\n",
+         log_warning( "match failed at point count %d != %" PORTuSIZE "\n",
                numPoints, model->m_points.size() );
          return false;
       }
@@ -878,7 +878,7 @@ bool Model::propEqual( const Model * model, int partBits, int propBits,
    {
       if (numTextures != model->m_materials.size())
       {
-         log_warning( "match failed at material count %d != %d\n",
+         log_warning( "match failed at material count %d != %" PORTuSIZE "\n",
                numTextures, model->m_materials.size() );
          return false;
       }
@@ -902,7 +902,7 @@ bool Model::propEqual( const Model * model, int partBits, int propBits,
    {
       if ( numProjections != model->m_projections.size() )
       {
-         log_warning( "match failed at projection count %d != %d\n",
+         log_warning( "match failed at projection count %d != %" PORTuSIZE "\n",
                numVertices, model->m_vertices.size() );
          return false;
       }
@@ -928,7 +928,7 @@ bool Model::propEqual( const Model * model, int partBits, int propBits,
    {
       if ( numSkelAnims != model->m_skelAnims.size() )
       {
-         log_warning( "match failed at skel anim count %d != %d\n",
+         log_warning( "match failed at skel anim count %d != %" PORTuSIZE "\n",
                numSkelAnims, model->m_skelAnims.size() );
          return false;
       }
@@ -947,7 +947,7 @@ bool Model::propEqual( const Model * model, int partBits, int propBits,
    {
       if ( numFrameAnims != model->m_frameAnims.size() )
       {
-         log_warning( "match failed at frameAnim count %d != %d\n",
+         log_warning( "match failed at frameAnim count %d != %" PORTuSIZE "\n",
                numFrameAnims, model->m_frameAnims.size() );
          return false;
       }
@@ -1092,7 +1092,7 @@ bool Model::mergeAnimations( Model * model )
    return true;
 }
 
-bool Model::mergeModels( Model * model, bool textures, AnimationMergeE animations, bool emptyGroups, double * trans, double * rot )
+bool Model::mergeModels( Model * model, bool textures, AnimationMergeE animations, bool emptyGroups, int point, double * trans, double * rot )
 {
    if ( m_animationMode )
    {
@@ -1116,6 +1116,33 @@ bool Model::mergeModels( Model * model, bool textures, AnimationMergeE animation
       mat.setTranslation( trans );
    }
 
+   Matrix pointOffset;
+
+   if ( point >= 0 && (unsigned int)point < m_points.size() )
+   {
+      pointOffset = mat;
+
+      // The MD3 filter doesn't rotate points correctly and has defacto changed their meaning.
+      Matrix pointSpace;
+      pointSpace.setRotationInDegrees( 90, 0, 90 );
+      pointOffset = pointOffset * pointSpace;
+
+      double rot[3];
+      double trans[3];
+      getPointRotation( point, rot );
+      getPointTranslation( point, trans );
+
+      Matrix m;
+      m.setRotation( rot );
+      m.setTranslation( trans );
+
+      mat = pointOffset * m;
+   }
+   else
+   {
+      point = -1;
+   }
+
    unsigned vertbase   = 0;
    unsigned tribase    = 0;
    unsigned grpbase    = 0;
@@ -1364,7 +1391,7 @@ bool Model::mergeModels( Model * model, bool textures, AnimationMergeE animation
    if ( frameAnimsNeeded )
    {
       setFrameAnimVertexCount( m_vertices.size() );
-      setFrameAnimPointCount( m_vertices.size() );
+      setFrameAnimPointCount( m_points.size() );
    }
 
    unsigned oldcount = getAnimCount( ANIMMODE_FRAME );
@@ -1401,35 +1428,51 @@ bool Model::mergeModels( Model * model, bool textures, AnimationMergeE animation
                unsigned f;
 
                unsigned vertcount = model->m_vertices.size();
+               unsigned pointcount = model->m_points.size();
 
                for ( f = 0; f < fc1; f++ )
                {
+                  Matrix fmat;
+
+                  if ( point != -1 )
+                  {
+                     double rot[3];
+                     double trans[3];
+
+                     getFrameAnimPointRotation( a, f, point, rot[0], rot[1], rot[2] );
+                     getFrameAnimPointCoords( a, f, point, trans[0], trans[1], trans[2] );
+
+                     fmat.setRotation( rot );
+                     fmat.setTranslation( trans );
+
+                     fmat = pointOffset * fmat;
+                  }
+                  else
+                  {
+                     fmat = mat;
+                  }
+
                   for ( unsigned v = 0; v < vertcount; v++ )
                   {
                      double coord[3] = { 0, 0, 0 };
                      model->getFrameAnimVertexCoords( a, f, v, coord[0], coord[1], coord[2] );
                      Vector vec( coord );
-                     vec = vec * mat;
+                     vec = vec * fmat;
                      setFrameAnimVertexCoords( a, f, v + vertbase, vec.get(0), vec.get(1), vec.get(2) );
                   }
-               }
 
-               unsigned pointcount = model->m_points.size();
-
-               for ( f = 0; f < fc1; f++ )
-               {
                   for ( unsigned p = 0; p < pointcount; p++ )
                   {
                      double coord[3] = { 0, 0, 0 };
                      model->getFrameAnimPointCoords( a, f, p, coord[0], coord[1], coord[2] );
                      Vector vec( coord );
-                     vec = vec * mat;
+                     vec = vec * fmat;
                      setFrameAnimPointCoords( a, f, p + pointbase, vec.get(0), vec.get(1), vec.get(2) );
 
                      model->getFrameAnimPointRotation( a, f, p, coord[0], coord[1], coord[2] );
                      Matrix m;
                      m.setRotation( coord );
-                     m = m * mat;
+                     m = m * fmat;
                      m.getRotation( coord );
                      setFrameAnimPointRotation( a, f, p + pointbase, coord[0], coord[1], coord[2] );
                   }
@@ -1454,35 +1497,51 @@ bool Model::mergeModels( Model * model, bool textures, AnimationMergeE animation
             unsigned f;
 
             unsigned vertcount = model->m_vertices.size();
+            unsigned pointcount = model->m_points.size();
 
             for ( f = 0; f < framecount; f++ )
             {
+               Matrix fmat;
+
+               if ( point != -1 )
+               {
+                  double rot[3];
+                  double trans[3];
+
+                  getFrameAnimPointRotation( n, f, point, rot[0], rot[1], rot[2] );
+                  getFrameAnimPointCoords( n, f, point, trans[0], trans[1], trans[2] );
+
+                  fmat.setRotation( rot );
+                  fmat.setTranslation( trans );
+
+                  fmat = pointOffset * fmat;
+               }
+               else
+               {
+                  fmat = mat;
+               }
+
                for ( unsigned v = 0; v < vertcount; v++ )
                {
                   double coord[3] = { 0, 0, 0 };
                   model->getFrameAnimVertexCoords( n, f, v, coord[0], coord[1], coord[2] );
                   Vector vec( coord );
-                  vec = vec * mat;
+                  vec = vec * fmat;
                   setFrameAnimVertexCoords( index, f, v + vertbase, vec.get(0), vec.get(1), vec.get(2) );
                }
-            }
 
-            unsigned pointcount = model->m_points.size();
-
-            for ( f = 0; f < framecount; f++ )
-            {
                for ( unsigned p = 0; p < pointcount; p++ )
                {
                   double coord[3] = { 0, 0, 0 };
                   model->getFrameAnimPointCoords( n, f, p, coord[0], coord[1], coord[2] );
                   Vector vec( coord );
-                  vec = vec * mat;
+                  vec = vec * fmat;
                   setFrameAnimPointCoords( index, f, p + pointbase, vec.get(0), vec.get(1), vec.get(2) );
 
                   model->getFrameAnimPointRotation( n, f, p, coord[0], coord[1], coord[2] );
                   Matrix m;
                   m.setRotation( coord );
-                  m = m * mat;
+                  m = m * fmat;
                   m.getRotation( coord );
                   setFrameAnimPointRotation( index, f, p + pointbase, coord[0], coord[1], coord[2] );
                }
@@ -1570,19 +1629,56 @@ bool Model::mergeModels( Model * model, bool textures, AnimationMergeE animation
       {
          unsigned framecount = getAnimFrameCount( ANIMMODE_FRAME, n );
          unsigned vertcount = model->m_vertices.size();
+         unsigned pointcount = model->m_points.size();
 
-         for ( unsigned v = 0; v < vertcount; v++ )
+         for ( unsigned f = 0; f < framecount; f++ )
          {
-            double coord[3] = { 0, 0, 0 };
-            model->getVertexCoords( v, coord );
+            Matrix fmat;
 
-            Vector vec( coord );
-            vec = vec * mat;
-
-            for ( unsigned f = 0; f < framecount; f++ )
+            if ( point != -1 )
             {
+               double rot[3];
+               double trans[3];
+
+               getFrameAnimPointRotation( n, f, point, rot[0], rot[1], rot[2] );
+               getFrameAnimPointCoords( n, f, point, trans[0], trans[1], trans[2] );
+
+               fmat.setRotation( rot );
+               fmat.setTranslation( trans );
+
+               fmat = pointOffset * fmat;
+            }
+            else
+            {
+               fmat = mat;
+            }
+
+            for ( unsigned v = 0; v < vertcount; v++ )
+            {
+               double coord[3] = { 0, 0, 0 };
+               model->getVertexCoords( v, coord );
+
+               Vector vec( coord );
+               vec = vec * fmat;
+
                setFrameAnimVertexCoords( n, f, v + vertbase, vec.get(0), vec.get(1), vec.get(2) );
             }
+
+            for ( unsigned p = 0; p < pointcount; p++ )
+            {
+               double coord[3] = { 0, 0, 0 };
+               model->getPointTranslation( p, coord );
+               Vector vec( coord );
+               vec = vec * fmat;
+               setFrameAnimPointCoords( n, f, p + pointbase, vec.get(0), vec.get(1), vec.get(2) );
+
+               model->getPointRotation( p, coord );
+               Matrix m;
+               m.setRotation( coord );
+               m = m * fmat;
+               m.getRotation( coord );
+               setFrameAnimPointRotation( n, f, p + pointbase, coord[0], coord[1], coord[2] );
+            }
          }
       }
    }
