@@ -70,7 +70,7 @@ struct MS3DVertex
 	uint8_t m_refCount;
 };
 
-const size_t FILE_VERTEX_SIZE = 15;
+//const size_t FILE_VERTEX_SIZE = 15;
 
 // Triangle information
 struct MS3DTriangle
@@ -101,7 +101,7 @@ struct MS3DMaterial
     char m_alphamap[128];
 };
 
-const size_t FILE_MATERIAL_SIZE = 361;
+//const size_t FILE_MATERIAL_SIZE = 361;
 
 //	Joint information
 struct MS3DJoint
@@ -115,7 +115,7 @@ struct MS3DJoint
 	uint16_t m_numTranslationKeyframes;
 };
 
-const size_t FILE_JOINT_SIZE = 93;
+//const size_t FILE_JOINT_SIZE = 93;
 
 // Keyframe data
 struct MS3DKeyframe
@@ -321,7 +321,7 @@ Model::ModelErrorE Ms3dFilter::readFile( Model * model, const char * const filen
       {
          if ( curTriangle->m_vertexIndices[i] >= numVertices )
          {
-            log_error( "vertex out of range: %d/%d\n", curTriangle->m_vertexIndices[i],
+            log_error( "vertex out of range: %d/%" PORTuSIZE "\n", curTriangle->m_vertexIndices[i],
                   modelVertices.size() );
             return Model::ERROR_BAD_DATA;
          }
@@ -349,7 +349,7 @@ Model::ModelErrorE Ms3dFilter::readFile( Model * model, const char * const filen
    uint16_t numGroups = 0;
    m_src->read( numGroups );
 
-   log_debug( "model says %d groups\n" );
+   log_debug( "model says %d groups\n", numGroups );
 
    for ( t = 0; t < numGroups; t++ )
    {
@@ -374,7 +374,7 @@ Model::ModelErrorE Ms3dFilter::readFile( Model * model, const char * const filen
          m_src->read( triIndex );
          if ( triIndex >= modelTriangles.size() )
          {
-            log_error( "triangle out of range: %d/%d\n",
+            log_error( "triangle out of range: %d/%" PORTuSIZE "\n",
                   triIndex, modelTriangles.size() );
             return Model::ERROR_BAD_DATA;
          }
@@ -1318,7 +1318,7 @@ void Ms3dFilter::writeVertexWeight( int subVersion,
       log_debug( "          new weights: %d, %d, %d, %d (total: %d)\n", weight[0], weight[1], weight[2], weight[3], weight[0] + weight[1] + weight[2] + weight[3] );
    }
 
-   if ( weight[0] + weight[1] + weight[2] + weight[3] != maxWeight ) {
+   if ( boneId[0] != 0xFF && weight[0] + weight[1] + weight[2] + weight[3] != maxWeight ) {
       log_warning( "write ms3d vertex weights: %d, %d, %d, %d (total: %d != %d)\n", weight[0], weight[1], weight[2], weight[3], weight[0] + weight[1] + weight[2] + weight[3], maxWeight );
    }
 
@@ -1485,6 +1485,12 @@ bool Ms3dFilter::readVertexWeight( int subVersion,
       m_src->read( extra2 ); // don't do anything with this
    }
 
+   // no weights defaults to full influence as if extra vertex data doesn't exist
+   if ( weights[0] == 0 && weights[1] == 0 && weights[2] == 0 )
+   {
+      weights[0] = 100;
+   }
+
    //log_debug( "      vtx %d: b %d, %d, %d, %d; w %d, %d, %d, %d\n", vertex,
    //   (int)boneIds[0], (int)boneIds[1], (int)boneIds[2], (int)boneIds[3],
    //   (int)weights[0], (int)weights[1], (int)weights[2], (int)weights[3] );
