@@ -205,7 +205,6 @@ bool ObjFilter::writeStripped( const char * fmt, ... )
    va_list ap;
    va_start( ap, fmt );
    PORT_vsnprintf( line, sizeof(line), fmt, ap );
-   replace( line, ',', '.' );
    va_end( ap );
 
    OFWS_StateE state = OFWS_Whitespace;
@@ -282,6 +281,7 @@ bool ObjFilter::writeStripped( const char * fmt, ... )
             }
             s++;
             d++;
+            break;
          case OFWS_AfterDecimal:
             if ( isdigit( line[s] ) )
             {
@@ -431,7 +431,7 @@ bool ObjFilter::writeMaterials()
             std::string filename = getRelativePath( m_modelPath.c_str(), m_model->getTextureFilename( m ) );
             char * filecpy = strdup( filename.c_str() );
             replaceSlash( filecpy );
-            writeStripped( "\tmap_Kd %s", 
+            writeLine( "\tmap_Kd %s",
                   ( (strncmp( filecpy, ".\\", 2 ) == 0 ) ? &filecpy[2] : filecpy ) );
             free( filecpy );
          }
@@ -517,7 +517,7 @@ bool ObjFilter::writeGroups()
 
    if ( tris.size() )
    {
-      writeLine( "# %d Ungrouped triangles", tris.size() );
+      writeLine( "# %" PORTuSIZE " Ungrouped triangles", tris.size() );
       writeLine( "" );
 
       writeLine( "o ungrouped" );
@@ -565,7 +565,7 @@ bool ObjFilter::writeGroups()
             }
          }
 
-         writeLine( "# %s, %d grouped triangles", grpStr, tris.size() );
+         writeLine( "# %s, %" PORTuSIZE " grouped triangles", grpStr, tris.size() );
          writeLine( "" );
 
          int matId = m_model->getGroupTextureId( g );
@@ -782,7 +782,15 @@ bool ObjFilter::readFace( char * line )
       int texidx  = -1;
       int normidx = -1;
 
-      vlist.push_back( v );
+      if ( v >= 0 && v < m_model->getVertexCount() )
+      {
+         vlist.push_back( v );
+      }
+      else
+      {
+         log_warning( "face with invalid vertex index %d\n", v );
+         return false;
+      }
 
       line = &line[len];
 
@@ -803,7 +811,15 @@ bool ObjFilter::readFace( char * line )
             {
                texidx = texidx - 1;
             }
-            vtlist.push_back( texidx );
+
+            if ( texidx >= 0 && (size_t) texidx < m_uvList.size() )
+            {
+               vtlist.push_back( texidx );
+            }
+            else if ( m_uvList.size() > 0 )
+            {
+               log_warning( "face with invalid texcoord index %d\n", texidx );
+            }
 
             while ( line[0] != '\0' && line[0] != '/' && !isspace( line[0] ) )
             {
@@ -1075,6 +1091,21 @@ bool ObjFilter::readMaterialLibrary( const char * filename )
 
          objmat->name = name;
       }
+      else if ( ptr[0] == '#' )
+      {
+         // ignore comment lines
+      }
+      else if ( !objmat )
+      {
+         char * keyword = ptr;
+         while ( ptr[0] && !isspace( ptr[0] ) )
+         {
+            ptr++;
+         }
+         ptr[0] = '\0';
+
+         log_warning( "Found keyword '%s' before newmtl in '%s'\n", keyword, filename );
+      }
       else if ( strncmp( "map_Kd", ptr, 6 ) == 0 )
       {
          ptr += 7;
@@ -1098,35 +1129,26 @@ bool ObjFilter::readMaterialLibrary( const char * filename )
       else if ( strncmp( "Kd ", ptr, 3 ) == 0 )
       {
          ptr += 3;
-         if ( objmat )
-         {
-            sscanf( ptr, "%f %f %f", 
-                  &objmat->diffuse[0], 
-                  &objmat->diffuse[1], 
-                  &objmat->diffuse[2] );
-         }
+         sscanf( ptr, "%f %f %f",
+               &objmat->diffuse[0],
+               &objmat->diffuse[1],
+               &objmat->diffuse[2] );
       }
       else if ( strncmp( "Ka ", ptr, 3 ) == 0 )
       {
          ptr += 3;
-         if ( objmat )
-         {
-            sscanf( ptr, "%f %f %f", 
-                  &objmat->ambient[0], 
-                  &objmat->ambient[1], 
-                  &objmat->ambient[2] );
-         }
+         sscanf( ptr, "%f %f %f",
+               &objmat->ambient[0],
+               &objmat->ambient[1],
+               &objmat->ambient[2] );
       }
       else if ( strncmp( "Ks ", ptr, 3 ) == 0 )
       {
          ptr += 3;
-         if ( objmat )
-         {
-            sscanf( ptr, "%f %f %f", 
-                  &objmat->specular[0], 
-                  &objmat->specular[1], 
-                  &objmat->specular[2] );
-         }
+         sscanf( ptr, "%f %f %f",
+               &objmat->specular[0],
+               &objmat->specular[1],
+               &objmat->specular[2] );
       }
       else if ( strncmp( "Ns ", ptr, 3 ) == 0 )
       {
