@@ -1,4 +1,4 @@
-/*  Misfit Model 3D
+/*  Maverick Model 3D
  * 
  *  Copyright (c) 2004-2007 Kevin Worcester
  * 
@@ -25,6 +25,7 @@
 #define __TEXTURE_H
 
 #include <stdint.h>
+#include <stdlib.h>
 #include <time.h>
 
 class Texture
@@ -73,6 +74,8 @@ class Texture
 
       static const char * errorToString( Texture::ErrorE );
 
+      void removeOpaqueAlphaChannel();
+
       char    * m_name;
       char    * m_filename;
       bool      m_isBad;
