@@ -1,4 +1,4 @@
-/*  Misfit Model 3D
+/*  Maverick Model 3D
  * 
  *  Copyright (c) 2004-2007 Kevin Worcester
  * 
@@ -25,6 +25,7 @@
 #define __TRANSLATE_H
 
 #include <string>
+#include <stdlib.h>
 
 #undef  QT_TRANSLATE_NOOP
 #define QT_TRANSLATE_NOOP( a, b ) b
