@@ -1,4 +1,4 @@
-/*  Misfit Model 3D
+/*  Maverick Model 3D
  * 
  *  Copyright (c) 2004-2007 Kevin Worcester
  * 
@@ -40,6 +40,7 @@
 
 #include <string.h>
 #include <errno.h>
+#include <stdlib.h>
 
 #include <string>
 #include <list>
@@ -70,7 +71,7 @@ static ModelList _models;
 
 static void _print_version( const char * progname )
 {
-   printf( "\nMisfit Model 3D, version %s\n\n", VERSION_STRING );
+   printf( "\nMaverick Model 3D, version %s\n\n", VERSION_STRING );
 }
 
 static void _print_help( const char * progname )
@@ -106,11 +107,14 @@ static void _print_help( const char * progname )
 
 static void _print_sysinfo()
 {
+   printf( "\nMaverick Model 3D, version %s\n\n", VERSION_STRING );
+
+#ifdef WIN32
+   // TODO: Get Windows version
+#else
    FILE * fp = NULL;
    char input[80];
 
-   printf( "\nMisfit Model 3D, version %s\n\n", VERSION_STRING );
-
    printf( "uname output:\n" );
    fp = popen( "uname -a", "r" );
    if ( fp )
@@ -142,6 +146,7 @@ static void _print_sysinfo()
    }
 
    printf("\n" );
+#endif
 
    exit(0);
 }
