@@ -1,4 +1,4 @@
-/*  Misfit Model 3D
+/*  Maverick Model 3D
  * 
  *  Copyright (c) 2004-2007 Kevin Worcester
  * 
@@ -39,9 +39,6 @@
 #include "selectfreecmd.h"
 #include "invertcmd.h"
 #include "invnormalcmd.h"
-//#include "jointcmd.h"
-#include "pointcmd.h"
-//#include "assignjointcmd.h"
 #include "subdividecmd.h"
 #include "makefacecmd.h"
 #include "rotatetexcmd.h"
@@ -155,12 +152,6 @@ int init_std_cmds( CommandManager * cmdMgr )
    cmd = new InvertSelectionCommand();
    cmdMgr->registerCommand( cmd );
 
-   // ----------------------
-
-   // This doesn't really do anything any more (use properties to rename)
-   //cmd = new PointCommand();
-   //cmdMgr->registerCommand( cmd );
-
    return 0;
 }
 
